@@ -1,19 +1,30 @@
 /*
  * ascii-xfr	Ascii file transfer.
  *
- * Usage:	ascii-xfr -s|-r [-dnv] [-c character delay] [-l line delay]
- *
- * Version:	@(#)ascii-xfr  1.00  18-Feb-1996  MvS.
+ * Usage:	ascii-xfr -s|-r [-ednv] [-c character delay] [-l line delay]
  *
  * 08.03.98 added a patch from Bo Branten <bosse@ing.umu.se>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: ascii-xfr.c,v 1.3 2003/04/19 18:06:58 al-guest Exp $")
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+#include <strings.h>
 #include <time.h>
-#include <fcntl.h>
+#include <sys/time.h>
+#include <sys/types.h>
+
+#ifdef HAVE_TERMIOS_H
+#include <termios.h>
+#endif
 
 /*
  *	Externals.
@@ -25,12 +36,11 @@ extern char *optarg;
 /*
  *	Global variables.
  */
-char *Version = "@(#)ascii-xfr  1.00  18-Feb-1996  MvS";
-
 int cdelay = 0;
 int ldelay = 0;
 int dotrans = 1;
 int eofchar = 26;
+int useeof = 0;
 int verbose = 0;
 time_t start;
 time_t last;
@@ -42,7 +52,7 @@ unsigned long bdone = 0;
 void ms_delay(ms)
 int ms;
 {
-#if defined(__linux__) || defined(BSD)
+#ifdef HAVE_USLEEP
   usleep(1000 * ms);
 #endif
 }
@@ -74,7 +84,8 @@ int force;
   if (!verbose) return;
 
   time(&now);
-  dif = now - last;
+  dif = now - start;
+  
   if (!force && dif < 2) return;
   if (dif < 1) dif = 1;
   last = now;
@@ -88,9 +99,20 @@ void check_answer()
 { /* a patch from Bo Branten <bosse@ing.umu.se> */
   char line[1024];
   int  n;
-
-  while((n = read(0, line, 1024)) > 0) {
+  fd_set rfds;
+  struct timeval tv;
+  
+  FD_ZERO (&rfds);
+  FD_SET (0, &rfds);
+  tv.tv_sec = 0;
+  tv.tv_usec = 0;
+  while (select (1, &rfds, NULL, NULL, &tv) > 0) {
+    n = read (0, line, 1024);
     write(2, line, n);
+    FD_ZERO (&rfds);
+    FD_SET (0, &rfds);
+    tv.tv_sec = 0;
+    tv.tv_usec = 0;
   }
 }
 
@@ -110,8 +132,6 @@ char *file;
 	return -1;
   }
 
-  fcntl(STDIN_FILENO, F_SETFL, O_NONBLOCK);
-
   while(fgets(line, 1024, fp) != NULL) {
 	if (dotrans && (s = strrchr(line, '\n')) != NULL) {
 		if (s > line && *(s - 1) == '\r')
@@ -132,8 +152,11 @@ char *file;
 	first = 0;
 	check_answer();
   }
-  putchar(eofchar);
+  if (useeof) 
+    putchar(eofchar);
   fflush(stdout);
+  if (isatty (1))
+    tcdrain (1);
   fclose(fp);
 
   return 0;
@@ -178,6 +201,7 @@ void usage()
 Usage: ascii-xfr -s|-r [-dvn] [-l linedelay] [-c character delay] filename\n\
        -s:  send\n\
        -r:  receive\n\
+       -e:  send the End Of File character (default is not to)\n\
        -d:  set End Of File character to Control-D (instead of Control-Z)\n\
        -v:  verbose (statistics on stderr output)\n\
        -n:  do not translate CRLF <--> LF\n\
@@ -194,7 +218,7 @@ char **argv;
   char *file;
   int ret;
 
-  while((c = getopt(argc, argv, "srdvnl:c:")) != EOF) {
+  while((c = getopt(argc, argv, "srdevnl:c:")) != EOF) {
 	switch(c) {
 		case 's':
 		case 'r':
@@ -203,6 +227,9 @@ char **argv;
 		case 'd':
 			eofchar = 4; /* Unix, CTRL-D */
 			break;
+		case 'e':
+			useeof = 1;
+			break;
 		case 'v':
 			verbose++;
 			break;
@@ -244,7 +271,7 @@ char **argv;
 	fprintf(stderr, "... Done.\n");
 	fflush(stdout);
   }
-
+  
   return (ret < 0 ? 1 : 0);
 }
 
