@@ -19,11 +19,16 @@
  *
  * 27.10.98 jl  converted do_log to use stdarg
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: common.c,v 1.2 2003/04/06 20:11:16 al-guest Exp $")
 
 #include "port.h" 
 #include "minicom.h"
 #include <stdarg.h>
-/* #include "intl.h" */
 
 #if _HAVE_MACROS
 /* Prefix a non-absolute file with the home directory. */
@@ -44,10 +49,10 @@ char *s;
 }
 #endif
 
-#ifdef LOGFILE
-/* Write a line to the log file.   jl 22.06.97 */
 void do_log(char *line, ...)
 {
+#ifdef LOGFILE
+/* Write a line to the log file.   jl 22.06.97 */
   FILE *logfile;
 #ifdef _HAVE_MACROS
   char *logname = pfix_home(logfname);
@@ -72,10 +77,7 @@ void do_log(char *line, ...)
   vfprintf(logfile, line, ap);
   fprintf(logfile, "\n");
   fclose(logfile);
-}
 #else
-void do_log(char *line, ...)
-{
-  /* dummy function, don't do anything */
-}
+  /* dummy, don't do anything */
 #endif
+}
