@@ -22,7 +22,17 @@
  *    jl 06.07.98 - the P_CONVCAP option
  *    jl 10.07.98 - moved functions pfix_home and do_log to file common.c
  *    jl 29.11.98 - the P_SHOWSPD option
+ *    jl 05.04.99 - logging options menu
+ *    er 18-Apr-99 - the P_MULTILINE option
+ *    jl 11.02.2000 - the P_STOPB option
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: config.c,v 1.5 2003/04/21 23:56:46 al-guest Exp $")
+
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
@@ -91,8 +101,8 @@ void read_parms()
 		P_PFULL(f) = 'N';
 	}
   }
-  p = mbasename(P_LOCK);
-  if (strncmp(p, "LCK", 3) == 0) *p = 0;
+  if ((p = strrchr(P_LOCK, '/')) != NULL && strncmp(p, "/LCK", 4) == 0)
+	*p = 0;
 }
 
 /*
@@ -191,9 +201,10 @@ WIN *w;
 int x, y;
 char *s;
 int len;
-int maxl;
+unsigned int maxl;
 {
   struct pars *p = (struct pars *)s;
+  char *home = NULL;
 
   if ((p->flags & PRIVATE) && real_uid != 0) {
   	werror(_("You are not allowed to change this parameter"));
@@ -201,6 +212,16 @@ int maxl;
   }
   wlocate(w, x, y);
   (void) wgets(w, s, len, maxl);
+  if (s[0] == '~' && (s[1] == '/' || s[1] == 0) &&
+    (home = getenv("HOME")) && strlen(s) + strlen(home) <= maxl) {
+    int i = 0;
+    memmove(s + strlen(home), s + 1, strlen(s));
+    memcpy(s, home, strlen(home));
+    wlocate(w, x, y);
+    for (i = 0; i < (len >= w->xs - x ? w->xs - x - 1 : len) && s[i]; i++)
+      wputc(w, s[i]);
+    wflush();
+  }
   p->flags |= CHANGED;
 }
 
@@ -245,30 +266,84 @@ static int rwxgetch()
   return(c);
 }
 
+#ifdef LOGFILE
+static void dologopt()
+{
+  WIN *w;
+  int c;
+  char *logfnstr = _(" A - File name (empty=disable) :"),
+       *logconn  = _(" B - Log connects and hangups  :"),
+       *logxfer  = _(" C - Log file transfers        :"),
+       *question = _("Change which setting?");
+
+  w = wopen(5, 4, 75, 8, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+
+  wtitle(w, TMID, _("Logging options"));
+  wprintf(w, "%s %s\n", logfnstr, P_LOGFNAME);
+  wprintf(w, "%s %s\n", logconn, _(P_LOGCONN));
+  wprintf(w, "%s %s\n", logxfer, _(P_LOGXFER));
+  wlocate(w, 4, 4);
+  wputs(w, question);
+  wredraw(w, 1);
+  while(1) {
+    wlocate(w, strlen(question) + 5, 5);
+    c = rwxgetch();
+    switch(c) {
+      case '\n':
+	wclose(w, 1);
+	return;
+      case 'A':
+	pgets(w, strlen(logfnstr) + 1, 0,
+	      P_LOGFNAME, PARS_VAL_LEN, PARS_VAL_LEN);
+	strcpy(logfname,P_LOGFNAME);
+	break;
+      case 'B':
+	strcpy(P_LOGCONN, yesno(P_LOGCONN[0] == 'N'));
+	wlocate(w, strlen(logconn) + 1, 1);
+	wprintf(w, "%s  ", _(P_LOGCONN));
+	markch(P_LOGCONN);
+	break;
+      case 'C':
+	strcpy(P_LOGXFER, yesno(P_LOGXFER[0] == 'N'));
+	wlocate(w, strlen(logxfer) + 1, 2);
+	wprintf(w, "%s  ", _(P_LOGXFER));
+	markch(P_LOGXFER);
+	break;
+      default:
+	break;
+    }
+  }
+}
+#endif
+
 static void dopath()
 {
   WIN *w;
   int c;
   char* download_directory = _(" A - Download directory :"),
-      * upload_directory = _(" B -   Upload directory :"),
-      * script_directory = _(" C -   Script directory :"),
-      * script_program = _(" D -     Script program :"),
-      * kermit_program = _(" E -     Kermit program :"),
+      * upload_directory = _(" B - Upload directory   :"),
+      * script_directory = _(" C - Script directory   :"),
+      * script_program = _(" D - Script program     :"),
+      * kermit_program = _(" E - Kermit program     :"),
+      * log_settings   = _(" F - Logging options"),
       * question = _("Change which setting?");
   
-  w = wopen(5, 5, 75, 11, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  w = wopen(5, 5, 75, 12, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
   wprintf(w, "%s %.44s\n", download_directory, P_DOWNDIR);
   wprintf(w, "%s %.44s\n", upload_directory, P_UPDIR);
   wprintf(w, "%s %.44s\n", script_directory, P_SCRIPTDIR);
   wprintf(w, "%s %.44s\n", script_program, P_SCRIPTPROG);
   wprintf(w, "%s %.44s\n", kermit_program, P_KERMIT);
-  wlocate(w, 4, 7);
+#ifdef LOGFILE
+  wprintf(w, "%s\n", log_settings);
+#endif
+  wlocate(w, 4, 8);
   wputs(w, question);
 
   wredraw(w, 1);
 
   while(1) {
-      wlocate(w, strlen (question) + 5, 7);
+      wlocate(w, strlen (question) + 5, 8);
       c = rwxgetch();
       switch(c) {
   	case '\n':
@@ -276,9 +351,11 @@ static void dopath()
   		return;
   	case 'A':
   		pgets(w, strlen (download_directory) + 1, 0, P_DOWNDIR, 64, 64);
+		init_dir('d');
   		break;
   	case 'B':
   		pgets(w, strlen (upload_directory) + 1, 1, P_UPDIR, 64, 64);
+		init_dir('u');
   		break;
   	case 'C':
   		pgets(w, strlen (script_directory) + 1, 2, P_SCRIPTDIR, 64, 64);
@@ -289,6 +366,11 @@ static void dopath()
   	case 'E':
   		pgets(w, strlen (kermit_program) + 1, 4, P_KERMIT, 64, 64);
   		break;
+#ifdef LOGFILE
+  	case 'F':
+		dologopt();
+		break;  
+#endif
   	default:
   		break;
       }
@@ -478,7 +560,8 @@ static void doserial()
   wprintf(w, "%s %.41s\n", lockfile_location, P_LOCK);
   wprintf(w, "%s %.41s\n", callin_program, P_CALLIN);
   wprintf(w, "%s %.41s\n", callout_program, P_CALLOUT);
-  wprintf(w, "%s %s %s%s1\n", bps_par_bits, P_BAUDRATE, P_BITS, P_PARITY);
+  wprintf(w, "%s %s %s%s%s\n",
+	  bps_par_bits, P_BAUDRATE, P_BITS, P_PARITY, P_STOPB);
   wprintf(w, "%s %s\n", hardware_flow_control, _(P_HASRTS));
   wprintf(w, "%s %s\n", software_flow_control, _(P_HASXON));
   wlocate(w, 4, 8);
@@ -504,14 +587,16 @@ static void doserial()
   		pgets(w, strlen (callout_program) + 1, 3, P_CALLOUT, 64, 64);
   		break;
   	case 'E':
-  		get_bbp(P_BAUDRATE, P_BITS, P_PARITY, 0);
+  		get_bbp(P_BAUDRATE, P_BITS, P_PARITY, P_STOPB, 0);
   		if (portfd >= 0) port_init();
   		wlocate(w, strlen (bps_par_bits) + 1, 4);
-		wprintf(w, "%s %s%s1  \n", P_BAUDRATE, P_BITS, P_PARITY);
+		wprintf(w, "%s %s%s%s  \n",
+			P_BAUDRATE, P_BITS, P_PARITY, P_STOPB);
 		if (st != NIL_WIN) mode_status();
 		markch(P_BAUDRATE);
 		markch(P_BITS);
 		markch(P_PARITY);
+		markch(P_STOPB);
 		break;
 	case 'F':
 		strcpy(P_HASRTS, yesno(P_HASRTS[0] == 'N'));
@@ -565,6 +650,7 @@ static void domodem()
       * auto_bps_detect = _(" Q - Auto bps detect ....."),
       * modem_has_dcd_line = _(" R - Modem has DCD line .."),
       * shown_speed = _(" S - Status line shows ..."),
+      * multi_node = _(" T - Multi-line untag ...."),
       * question = _("Change which setting?");
 
   w = wopen(2, 2, 77, 22, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
@@ -597,6 +683,8 @@ static void domodem()
   wprintf(w, "%s %s\n", modem_has_dcd_line, _(P_HASDCD));
   wlocate(w, 34, 17);
   wprintf(w, "%s %s\n", shown_speed, sspd(P_SHOWSPD));
+  wlocate(w, 34, 18); /* Option for multi-node untag */
+  wprintf(w, "%s %s\n", multi_node, _(P_MULTILINE));	/* er 18-Apr-99 */
 
   wlocate(w, 1, 20);
   wprintf(w, "%s ", question);
@@ -692,6 +780,12 @@ static void domodem()
 			wputs(w, sspd(P_SHOWSPD));
 			mode_status();
 			break;
+		case 'T': /* Update for multi-node */
+			psets(P_MULTILINE, yesno(P_MULTILINE[0] == 'N' ));
+			wlocate(w, 35 + strlen(multi_node), 18);
+			wputs(w, _(P_MULTILINE));
+			break;
+							/* er 18-Apr-99 */
 		case '\n':
   			dirflush = 1;
   			wclose(w, 1);
@@ -728,12 +822,12 @@ static void doscrkeyb()
       * foreground_color_stat = _(" I - Foreground Color (stat):"),
       * background_color_stat = _(" J - Background Color (stat):"),
       * history_buffer_size = _(" K - History Buffer Size    :"),
-      * macros_file = _(" L - Macros file            :"),
-      * macros_enabled = _(" N - Macros enabled         :"),
-      * character_conversion = _(" O - Character conversion   :"),
       * question = _("Change which setting?  (Esc to exit)");
-
 #if _HAVE_MACROS
+  char* macros_file = _(" L - Macros file            :"),
+      * macros_enabled = _(" N - Macros enabled         :"),
+      * character_conversion = _(" O - Character conversion   :");
+
   FILE	*fp;
 
   miny = 3;
@@ -1050,24 +1144,28 @@ int dotermmenu()
   int new_term = -1;
   int old_stat = P_STATLINE[0];
   extern int use_status;
+  char buf[8];
+  extern int vt_nl_delay;
   char* terminal_emulation = _(" A - Terminal emulation  :"),
       * backspace_key_sends = _(" B - Backspace key sends :"),
       * status_line = _(" C -      Status line is :"),
+      * msg_nl_delay = _(" D -  Newline delay (ms) :"),
       * question = _("Change which setting?");
 
-  w = wopen(20, 7, 59, 13, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  w = wopen(20, 7, 59, 14, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
   wtitle(w, TMID, _("Terminal settings"));
   wprintf(w, "\n");
   wprintf(w, "%s %s\n", terminal_emulation, terminal == VT100 ? "VT102" : "ANSI");
   wprintf(w, "%s %s\n", backspace_key_sends, P_BACKSPACE);
   wprintf(w, "%s %s\n", status_line, _(P_STATLINE));
-  wlocate(w, 4, 5);
+  wprintf(w, "%s %d\n", msg_nl_delay, vt_nl_delay);
+  wlocate(w, 4, 6);
   wputs(w, question);
 
   wredraw(w, 1);
 
   while(1) {
-      wlocate(w, strlen (question) + 5, 5);
+      wlocate(w, strlen (question) + 5, 6);
       c = rwxgetch();
       switch(c) {
   	case '\n':
@@ -1113,6 +1211,14 @@ int dotermmenu()
 		wlocate(w, strlen (status_line) + 1, 3);
 		wprintf(w, "%s ", _(P_STATLINE));
 		break;
+	case 'D':
+		sprintf(buf, "%d", vt_nl_delay);
+		wlocate(w, strlen(msg_nl_delay) +1, 4);
+		wgets(w, buf, 4, 4);
+		vt_nl_delay = atoi(buf);
+		wlocate(w, strlen(msg_nl_delay) +1, 4);
+		wprintf(w, "%-3d", vt_nl_delay);
+		break;
   	default:
   		break;
       }
@@ -1207,7 +1313,7 @@ static void donamsave()
   ifile[0] = 0;
   s = input(_("Give name to save this configuration?"), ifile);
   if (s != (char *)0 && *s != 0) {
-  	snprintf(parfile, sizeof(parfile), "%s/minirc.%s", LIBDIR, s);
+  	snprintf(parfile, sizeof(parfile), "%s/minirc.%s", CONFDIR, s);
   dodflsave();
   }
 }
@@ -1247,7 +1353,7 @@ int setup;
   char *s;
 
   /* Find out extension of parameter file */
-  s = parfile + strlen(LIBDIR) + 8;
+  s = parfile + strlen(CONFDIR) + 8;
   snprintf(some_string, sizeof(some_string), _("Save setup as %s"), s);
 
   if (!setup) menu1[8] = MENU_END;
@@ -1259,21 +1365,22 @@ int setup;
 
 /* fmg 1/11/94 Color names for menu */
 
-static char *J_col[] =
+char *J_col[] =
   { N_("BLACK"), N_("RED"), N_("GREEN"), N_("YELLOW"),
     N_("BLUE"), N_("MAGENTA"), N_("CYAN"), N_("WHITE") };
 
 static char *speeds[] =
    { "300", "1200", "2400", "4800" , 
-     "9600", "19200", "38400", "57600", "115200", "Curr" };
+     "9600", "19200", "38400", "57600", "115200", "230400", "Curr" };
 
 /*
  * Ask user for Baudrate, Bits and Parity
  */
-void get_bbp(ba, bi, pa, curr_ok)
+void get_bbp(ba, bi, pa, stopb, curr_ok)
 char *ba;
 char *bi;
 char *pa;
+char *stopb;
 int curr_ok;
 {
   int c;
@@ -1281,38 +1388,42 @@ int curr_ok;
   int x, y;
   int max = m_getmaxspd();
 
-  w = wopen(21, 4, 60, 20, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
+  w = wopen(21, 3, 60, 20, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
   wtitle(w, TMID, _("Comm Parameters"));
 
   dirflush = 0;
 
   wlocate(w, 0, 3);
   wputs(w, _("   Speed          Parity          Data\n\n"));
-  wputs(w, _(" A: 300           K: None         R: 5\n"));
-  wputs(w, _(" B: 1200          L: Even         S: 6\n"));
-  wputs(w, _(" C: 2400          M: Odd          T: 7\n"));
-  wputs(w, _(" D: 4800          N: Mark         U: 8\n"));
-  wputs(w, _(" E: 9600\n"));
+  wputs(w, _(" A: 300           L: None         S: 5\n"));
+  wputs(w, _(" B: 1200          M: Even         T: 6\n"));
+  wputs(w, _(" C: 2400          N: Odd          U: 7\n"));
+  wputs(w, _(" D: 4800          O: Mark         V: 8\n"));
+  wputs(w, _(" E: 9600          P: Space\n"));
   if (max > 96)
-	wputs(w, _(" F: 19200         O: Space\n"));
+	wputs(w, _(" F: 19200                      Stopbits\n"));
   else
-	wputs(w, _("                  O: Space\n"));
+	wputs(w, "                               Stopbits\n");
   if (max > 192)
-	wputs(w, _(" G: 38400\n"));
+	wputs(w, _(" G: 38400                         W: 1\n"));
   else
-	wputs(w, "\n");
+	wputs(w, _("                                    W: 1\n"));
   if (max > 384)
-	wputs(w, _(" H: 57600\n"));
+	wputs(w, _(" H: 57600                         X: 2\n"));
+  else
+	wputs(w, "                                    X: 2\n");
+  if (max > 576)
+	wputs(w, _(" I: 115200        Q: 8-N-1\n"));
+  else
+	wputs(w, _("                  Q: 8-N-1\n"));
+  if (max > 1152)
+	wputs(w, _(" J: 230400        R: 7-E-1\n"));
+  else
+	wputs(w, _("                  R: 7-E-1\n"));
+  if (curr_ok)
+	wputs(w, _(" K: Current\n"));
   else
 	wputs(w, "\n");
-  if (max > 576)
-	wputs(w, _(" I: 115200        P: 8-N-1\n"));
-  else
-	wputs(w, _("                  P: 8-N-1\n"));
-  if (curr_ok)
-	wputs(w, _(" J: Current       Q: 7-E-1\n"));
-  else
-	wputs(w, _("                  Q: 7-E-1\n"));
   wputs(w, _("\n Choice, or <Enter> to exit? "));
   x = w->curx;
   y = w->cury;
@@ -1324,12 +1435,14 @@ int curr_ok;
 
   while(1) {
   	wlocate(w, 1, 1);
-  	wprintf(w, _("Current: %5s %s%s1  "), ba, bi, pa);
+  	wprintf(w, _("Current: %5s %s%s%s  "), ba, bi, pa, stopb);
   	wlocate(w, x, y);
   	wflush();
   	c = wxgetch();
   	if (c >= 'a') c -= 32;
   	switch(c) {
+  		case 'J':
+			if (max < 2304) break;
   		case 'I':
 			if (max < 1152) break;
   		case 'H':
@@ -1343,45 +1456,53 @@ int curr_ok;
   		case 'C':
   		case 'D':
   		case 'E':
-		case 'J':
-			if (c == 'J' && !curr_ok) break;
+  		case 'K':
+			if (c == 'K' && !curr_ok) break;
   			strcpy(ba, speeds[c - 'A']);
   			break;
-  		case 'K':
-  			pa[0] = 'N';
-  			break;
   		case 'L':
-  			pa[0] = 'E';
+  			pa[0] = 'N';
   			break;
   		case 'M':
+  			pa[0] = 'E';
+  			break;
+  		case 'N':
   			pa[0] = 'O';
   			break;
-		case 'N':
+		case 'O':
 			pa[0] = 'M';
 			break;
-		case 'O':
+		case 'P':
 			pa[0] = 'S';
 			break;
-  		case 'P':
+  		case 'Q':
   			pa[0] = 'N';
   			bi[0] = '8';
-  			break;
-  		case 'Q':
-  			pa[0] = 'E';
-  			bi[0] = '7';
+			stopb[0] = '1';
   			break;
   		case 'R':
-  			bi[0] = '5';
+  			pa[0] = 'E';
+  			bi[0] = '7';
+			stopb[0] = '1';
   			break;
   		case 'S':
-  			bi[0] = '6';
+  			bi[0] = '5';
   			break;
   		case 'T':
-  			bi[0] = '7';
+  			bi[0] = '6';
   			break;
   		case 'U':
+  			bi[0] = '7';
+  			break;
+  		case 'V':
   			bi[0] = '8';
   			break;
+  		case 'W':
+  			stopb[0] = '1';
+			break;
+  		case 'X':
+  			stopb[0] = '2';
+			break;
   		case 27:
   		case '\n':
   		case '\r':
@@ -1585,25 +1706,25 @@ void doconv()
       strcpy(buf,P_CONVF);
       prompt=_("Load file: %s");
       wprintf(w, prompt, buf);
-      pgets(w, strlen(prompt) - 1, ymax - 1, buf, 64, 64);
-      if (loadconv(buf) == 0) {
+      pgets(w, strlen(prompt) - 1, ymax - 1, P_CONVF, 64, 64);
+      if (loadconv(P_CONVF) == 0) {
 	if(strcmp(P_CONVF,buf))
 	  markch(P_CONVF);
-	strcpy(P_CONVF,buf);
 	redraw=1;
-      }
+      } else
+	strcpy(P_CONVF,buf);
       break;
     case 'B':
       strcpy(buf,P_CONVF);
       prompt=_("Save as file: %s");
       wprintf(w, prompt, buf);
-      pgets(w, strlen(prompt) - 1, ymax - 1, buf, 64, 64);
-      if (saveconv(buf) == 0) {
+      pgets(w, strlen(prompt) - 1, ymax - 1, P_CONVF, 64, 64);
+      if (saveconv(P_CONVF) == 0) {
 	if(strcmp(P_CONVF,buf))
 	  markch(P_CONVF);
-	strcpy(P_CONVF,buf);
 	redraw=1;
-      }
+      } else
+	strcpy(P_CONVF,buf);
       break;
     case 'C':
       prompt=_("Character to be edited: ");
