@@ -2,8 +2,6 @@
  * dial.c	Functions to dial, retry etc. Als contains the dialing
  *		directory code, _and_ the famous tu-di-di music.
  *
- *		$Id: dial.c,v 1.2 1999/09/03 12:23:09 walker Exp $
- *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
  *
@@ -22,14 +20,21 @@
  *   er 18-Apr-99 When calling a multiline BBS
  *		  tagged entries with same name are untagged
  *   jl 01.09.99  Move entry up/down in directory
+ *   jl 10.02.2000 Stopbits field added
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: dial.c,v 1.6 2003/04/21 23:56:46 al-guest Exp $")
 
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
 
 #if VC_MUSIC
-#  if defined(__linux__)
+#  if defined(__GLIBC__)
 #    include <sys/ioctl.h>
 #    include <sys/kd.h>
 #    include <sys/time.h>
@@ -39,19 +44,6 @@
 #  endif
 #endif
 
-/* We want the ANSI offsetof macro to do some dirty stuff. */
-#ifndef offsetof
-#  define offsetof(type, member) ((int) &((type *)0)->member)
-#endif
-
-/* Values for the "flags". */
-#define FL_ECHO		0x01	/* Local echo on/off. */
-#define FL_DEL		0x02	/* Backspace or DEL */
-#define FL_WRAP		0x04	/* Use autowrap. */
-#define FL_ANSI		0x08	/* Type of term emulation */
-#define FL_TAG		0x80	/* This entry is tagged. */
-#define FL_SAVE		0x0f	/* Which portions of flags to save. */
-
 /* Dialing directory. */
 struct v1_dialent {
   char name[32];
@@ -99,7 +91,7 @@ struct dialent {
   char lasttime[9];	/* jl 22.06.97 */
   int  count;		/* jl 22.06.97 */
   char convfile[16];	/* jl 21.09.97 */
-  char stopb[2];	/* jl 07.01.2000 */
+  char stopb[2]; 	/* jl 10.02.2000 */
   struct dialent *next;
 };
 
@@ -108,7 +100,7 @@ struct dialent {
 struct dver {
   short magic;
   short version;
-  short size;
+  unsigned short size;
   short res1;
   short res2;
   short res3;
@@ -127,8 +119,8 @@ static int newtype;
 /* Access to ".dialdir" denied? */
 static int dendd = 0;
 static char *tagged;
-static char *dial_user;
-static char *dial_pass;
+char *dial_user;
+char *dial_pass;
 
 /*
  * Functions to talk to the modem.
@@ -250,8 +242,8 @@ void hangup()
   /* If we don't have DCD support fake DCD dropped */
   bogus_dcd = 0;
   wclose(w, 1);
-
-  if (st) time_status();
+  if (st)
+    time_status();
 }
 
 /*
@@ -348,7 +340,7 @@ int rtime;
   	wlocate(dialwin, 0, 6);
 	wprintf(dialwin, _("     Retry in %2d seconds             "), f);
   }
-#ifdef __linux__
+#ifdef HAVE_USLEEP
   /* MARK updated 02/17/94 - Min dial delay set to 0.35 sec instead of 1 sec */
   if (f < 0) usleep(350000); /* Allow modem time to hangup if redial time == 0 */
 #else
@@ -468,7 +460,7 @@ MainLoop:
 	buf[0] = 0;
 	while(dialtime > 0) {
 	    if (*s == 0) {
-		x = check_io(portfd, 0, 1000, buf, NULL);
+		x = check_io(portfd_connected, 0, 1000, buf, NULL);
 		s = buf;
 	    }
 	    if (x & 2) {
@@ -526,7 +518,7 @@ MainLoop:
 				ptime->tm_hour,ptime->tm_min);
 			d->count ++;
 
-#ifdef _HAVE_MACROS
+#if _HAVE_MACROS
 			if (d->convfile[0]) {
 			  loadconv(d->convfile);    /* jl 21.09.97 */
 			  strcpy(P_CONVF, d->convfile);
@@ -700,8 +692,7 @@ FILE *fp;
   d->lasttime[0]=0;
   d->count=0;
   d->convfile[0]=0;
-  d->stopb[0]='1';
-  d->stopb[1]=0;
+  strcpy(d->stopb, "1");
 }
 
 /* Read version 2 of the dialing directory. */
@@ -718,8 +709,7 @@ FILE *fp;
   d->lasttime[0]=0;
   d->count=0;
   d->convfile[0]=0;
-  d->stopb[0]='1';
-  d->stopb[1]=0;
+  strcpy(d->stopb, "1");
 }
 
 /* Read version 1 of the dialing directory. */
@@ -738,8 +728,7 @@ struct dialent *d;
   d->lasttime[0]=0;
   d->count=0;
   d->convfile[0]=0;
-  d->stopb[0]='1';
-  d->stopb[1]=0;
+  strcpy(d->stopb, "1");
 }
 
 /* Read version 0 of the dialing directory. */
@@ -906,11 +895,11 @@ int readdialdir()
     if (snprintf(copycmd,sizeof(copycmd),
 	     "cp %s %s.%hd",dfile,dfile,dial_ver.size) > 0) {
       if (P_LOGFNAME[0] != 0)
-	do_log(copycmd);
+	do_log("%s", copycmd);
       if (system(copycmd) == 0) {
 	snprintf(copycmd,sizeof(copycmd),
 		 _("Old dialdir copied as %s.%hd"),dfile,dial_ver.size);
-	w=mc_tell(copycmd);
+	w=mc_tell("%s", copycmd);
 	if (w) {
 	  sleep(2);
 	  wclose(w,1);
@@ -1292,7 +1281,7 @@ struct dialent *d;
   }
   newtype = d->term;
   vt_set(-1, d->flags & FL_WRAP, NULL, -1, -1, d->flags & FL_ECHO, -1, -1);
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   local_echo = d->flags & FL_ECHO;
 #endif
   if (newtype != terminal)
@@ -1349,10 +1338,11 @@ char *entry;
   while (s) {
     /* Find entry. */
     if ((num = atoi(s)) != 0) {
-      d = getno(num - 1);
-      d->flags |= FL_TAG;
-      if (d1 == (struct dialent *)NULL)
-	d1 = d;
+      if ((d = getno(num - 1))) {
+	d->flags |= FL_TAG;
+	if (d1 == (struct dialent *)NULL)
+	  d1 = d;
+      }
     } else {
       for(d = dialents; d; d = d->next)
 	if (strstr(d->name, s)) {
@@ -1397,7 +1387,7 @@ void dialdir()
   int changed = 0;
   static char *tag_exit  = N_("( Escape to exit, Space to tag )"),
     	      *move_exit = N_(" Move entry up/down, Escape to exit");
-  int tagmvlen = 0;
+  unsigned int tagmvlen = 0;
   int position_dialing_directory = ((COLS / 2) + 32 - strlen (_(what))) / 2;
 
   dprev = -1;
@@ -1426,7 +1416,7 @@ void dialdir()
 
   prdir(w, top, top);  
   wlocate(w, position_dialing_directory, w->ys - 1);
-  wprintf(w, "%*.*s", tagmvlen,tagmvlen, _(tag_exit));
+  wprintf(w, "%*.*s", tagmvlen,tagmvlen, tag_exit);
   dhili(position_dialing_directory, subm);
   dirflush = 1;
   wredraw(dsub, 1);
@@ -1680,13 +1670,13 @@ again:
   /* Move the entry up/down in directory. */
   if (subm == 5) {
 	wlocate(w, position_dialing_directory, w->ys - 1);
-	wprintf(w, "%*.*s", tagmvlen,tagmvlen, _(move_exit));
+	wprintf(w, "%*.*s", tagmvlen,tagmvlen, move_exit);
 	cur = move_entry (w, d, cur, &top);
 	if (cur != ocur)
 	  changed++;
 	ocur = cur;
 	wlocate(w, position_dialing_directory, w->ys - 1);
-	wprintf(w, "%*.*s", tagmvlen,tagmvlen, _(tag_exit));
+	wprintf(w, "%*.*s", tagmvlen,tagmvlen, tag_exit);
   }
 
   /* Dial a number manually. */
