@@ -8,32 +8,30 @@
  *	by Miquel van Smoorenburg.  Written by James S. Seymour.
  *	Copyright (c) 1998 by James S. Seymour (jseymour@jimsun.LinxNet.com)
  *      Some mods for i18n  
- *         Copyright (c) 1998 by Arnaldo Carvalho de Melo <acme@conectiva.com.br>
+ *      Copyright (c) 1998 by Arnaldo Carvalho de Melo <acme@conectiva.com.br>
  *
  *	This program is free software; you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License
  *	as published by the Free Software Foundation; either version
  *	2 of the License, or (at your option) any later version.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: file.c,v 1.4 2003/04/21 23:56:46 al-guest Exp $")
+
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
 #include "getsdir.h"
 
-_PROTO(extern int wildmat, (char *s, char *p));
-
-/* We want the ANSI offsetof macro to do some dirty stuff. */
-#ifndef offsetof
-#  define offsetof(type, member) ((int) &((type *)0)->member)
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
 #endif
 
-/* Values for the "flags". */
-#define FL_ECHO		0x01	/* Local echo on/off. */
-#define FL_DEL		0x02	/* Backspace or DEL */
-#define FL_WRAP		0x04	/* Use autowrap. */
-#define FL_ANSI		0x08	/* Type of term emulation */
-#define FL_TAG		0x80	/* This entry is tagged. */
-#define FL_SAVE		0x0f	/* Which portions of flags to save. */
+_PROTO(extern int wildmat, (char *s, char *p));
 
 #define FILE_MWTR 1	/* main window top row */
 #define SUBM_OKAY 5	/* last entry in sub-menu */
@@ -48,7 +46,7 @@ _PROTO(static GETSDIR_ENTRY *getno, (int no, GETSDIR_ENTRY *dirdat));
 _PROTO(static void dhili, (int k));
 _PROTO(static void prdir, (WIN *dirw, int top, int cur, \
     GETSDIR_ENTRY *dirdat, int longest));
-_PROTO(static void prone, (WIN *dirw, int top, int cur, \
+_PROTO(static void prone, (WIN *dirw, \
     GETSDIR_ENTRY *dirdat, int longest, int inverse));
 _PROTO(static void *set_work_dir, (void *existing, size_t min_len));
 _PROTO(static int new_filedir, (GETSDIR_ENTRY *o_dirdat, int flushit));
@@ -77,7 +75,7 @@ char *s;
 {
   WIN *w;
 
-  w = mc_tell(s);
+  w = mc_tell("%s", s);
   sleep(1);
   wclose(w, 1);
 }
@@ -177,9 +175,8 @@ int longest;
  * Print one directory entry.
  */
 static void
-prone(dirw, top, cur, dirdat, longest, inverse)
+prone(dirw, dirdat, longest, inverse)
 WIN *dirw;
-int top, cur;
 GETSDIR_ENTRY *dirdat;
 int longest;
 int inverse;
@@ -233,6 +230,27 @@ static int down_loading = 0;
 static char *ret_buf = NULL;
 
 
+/* Init up/down work directories to make sure we start from
+ * the configuration defaults on the next up/download. jl 6/2000
+ */
+void init_dir(char dir)
+{
+  char *p = NULL;
+  
+  switch (dir) {
+  case 'u':
+    p=u_work_dir;
+    u_work_dir = (char *) NULL;
+    break;
+  case 'd':
+    p=d_work_dir;
+    d_work_dir = (char *) NULL;
+    break;
+  }
+  free ((void *) p);
+  return;
+}
+
 static void *
 set_work_dir(existing, min_len)
 void *existing;
@@ -240,8 +258,7 @@ size_t min_len;
 {
     void *vp;
 
-    vp = existing == NULL? 
-      (void *)malloc(min_len) : (void *)realloc(existing, min_len);
+    vp = existing == NULL ? (void *)malloc(min_len) : (void *)realloc(existing, min_len);
 
     if(down_loading)
 	d_work_dir = vp;
@@ -557,14 +574,14 @@ again:
 	d = getno(cur, dirdat);
 	/*
 	if(S_ISDIR(d->mode))
-	    prone(main_w, top, top, d, longest, 0);	
+	    prone(main_w, d, longest, 0);	
 	*/
 	switch(c = wxgetch()) {
 	    case K_UP:
 	    case 'k':
 		/*
 		if(S_ISDIR(d->mode))
-		    prone(main_w, top, top, d, longest, 1);	
+		    prone(main_w, d, longest, 1);	
 		*/
 		cur -= (cur > 0);
 		break;
@@ -572,7 +589,7 @@ again:
 	    case 'j':
 		/*
 		if(S_ISDIR(d->mode))
-		    prone(main_w, top, top, d, longest, 1);	
+		    prone(main_w, d, longest, 1);	
 		*/
 		cur += (cur < nrents - 1);
 		break;
@@ -624,7 +641,7 @@ again:
 			else
 			    --tag_cnt;
 			wlocate(main_w, 0, cur + FILE_MWTR - top);
-			prone(main_w, top, top, d, longest, d->cflags & FL_TAG);	
+			prone(main_w, d, longest, d->cflags & FL_TAG);	
 			wputc(main_w, '\n');
 			cur += (cur < nrents - 1);
 		    }
