@@ -14,6 +14,13 @@
  *
  *  // jl 23.06.97 adjustable DTR drop time
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: functions.c,v 1.1.1.1 2003/03/30 18:55:49 al-guest Exp $")
+
 #include "port.h"
 #include "minicom.h"
 
