@@ -1,6 +1,6 @@
 /*
  * ipc.c	talk to the keyserv process.
- * 
+ *
  *		Entry point:
  *
  *		keyserv(command, arg)
@@ -15,11 +15,20 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: ipc.c,v 1.6 2003/04/19 16:31:27 al-guest Exp $")
+
+#include <strings.h>
+
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
 
-#ifndef _SELECT
+#ifndef HAVE_SELECT
 
 static int tokeyserv, fromkeyserv;	/* File desciptors of ipc pipes */
 static int keypid;			/* pid of keyserv  		*/
@@ -54,8 +63,8 @@ int dummy;
 {
   signal(ACK, sigack);
   if (waiting) longjmp(ackjmp, 1);
-  printf(_("sigack: unexpected ACK signal &^%%$!! (pardon my French)%c\n",
-	   '\r'));
+  printf(_("sigack: unexpected ACK signal &^%%$!! (pardon my French)%c\n"),
+	   '\r');
 }
 
 /*
@@ -99,7 +108,7 @@ static void kinstall()
 		/* Close unused file descriptors */
 		close(pipe1[1]);
 		close(pipe2[0]);
-		snprintf(prog, sizeof(prog), "%s/keyserv", LIBDIR);
+		snprintf(prog, sizeof(prog), "%s/keyserv", CONFDIR);
   		execl(prog, "keyserv", mpid, (char *)NULL);
   		exit(0);
   	default: /* Parent */
@@ -187,12 +196,17 @@ int cmd, arg;
   return(0);
 }
 
-/* Dummy sigalarm handler. */
-static void dummy()
+/* Dummy function, e.g. sigalarm handler. */
+void empty_function()
 {
 }
 
-/* Wait for I/O to happen. We might get interrupted by keyserv. */
+/* Wait for I/O to happen. We might get interrupted by keyserv.
+ *
+ * Socket-mode: If reading fd1 fails and fd1 is our portfd and it's the
+ *              socket, the socket is closed.
+ */
+
 int check_io(fd1, fd2, tmout, buf, buflen)
 int fd1;
 int fd2;
@@ -204,7 +218,7 @@ int *buflen;
   int x = 0;
 
   /* OK, set the alarm if needed. */
-  signal(SIGALRM, dummy);
+  signal(SIGALRM, empty_function);
   if (tmout) alarm((tmout + 500) / 1000);
 
   /* We do a read on the first fd, the second one is always stdin. */
@@ -212,6 +226,10 @@ int *buflen;
 	if (fd1 >= 0) {
 		/* Read gets interrupted by keypress or alarm. */
 		n = read(fd1, buf, 127);
+#ifdef USE_SOCKET
+		if (!n && portfd_is_socket && portfd == fd1)
+			term_socket_close();
+#endif /* USE_SOCKET */
 		buf[n > 0 ? n : 0] = 0;
 		if (buflen) *buflen = n;
 		if (n > 0) x |= 1;
@@ -226,7 +244,7 @@ int *buflen;
   return(x);
 }
 
-#else /* _SELECT */
+#else /* HAVE_SELECT */
 
 /* Check if there is IO pending. */
 int check_io(fd1, fd2, tmout, buf, buflen)
@@ -259,7 +277,13 @@ int *buflen;
   /* If there is data put it in the buffer. */
   if (buf) {
 	i = 0;
-	if ((n & 1) == 1) i = read(fd1, buf, 127);
+	if ((n & 1) == 1) {
+		i = read(fd1, buf, 127);
+#ifdef USE_SOCKET
+		if (!i && portfd_is_socket && portfd == fd1)
+			term_socket_close();
+#endif /* USE_SOCKET */
+	}
 	buf[i > 0 ? i : 0] = 0;
 	if (buflen) *buflen = i;
   }
@@ -297,4 +321,4 @@ int cmd, arg;
   return(0);
 }
 
-#endif /* _SELECT */
+#endif /* HAVE_SELECT */
