@@ -12,36 +12,60 @@
  * fmg 1/11/94 color mods
  * jl  22.06.97 log it when DCD drops
  * jl  02.06.98 added call duration to the "Gone offline" log line
+ * jl  14.06.99 moved lockfile creation to before serial port opening
  *
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: main.c,v 1.7 2003/05/10 18:10:37 al-guest Exp $")
+
 #include "port.h"
 #include "minicom.h"
-#include "patchlevel.h"
 #include "intl.h"
-#if defined(__linux__) || (defined(BSD) && (BSD >= 199306))
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
 
+#ifdef SVR4_LOCKS
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/mkdev.h>
+#endif /* SVR4_LOCKS */
+
 static jmp_buf albuf;
 
 /* Compile SCCS ID into executable. */
-char *Version = SCCS_ID;
+char *Version = VERSION;
 
 void curs_status();
 
 /*
- * Return the last part of a filename.
+ * Find out name to use for lockfile when locking tty.
  */
-char *mbasename(s)
-char *s;
+char *mbasename(char *s, char *res, int reslen)
 {
   char *p;
   
-  if((p = strrchr(s, '/')) == (char *)NULL)
-  	p = s;
-  else
-  	p++;
-  return(p);
+  if (strncmp(s, "/dev/", 5) == 0) {
+	/* In /dev */
+	strncpy(res, s + 5, reslen - 1);
+	res[reslen-1] = 0;
+	for (p = res; *p; p++)
+		if (*p == '/') *p = '_';
+  } else {
+	/* Outside of /dev. Do something sensible. */
+	if ((p = strrchr(s, '/')) == NULL)
+  		p = s;
+	else
+  		p++;
+	strncpy(res, p, reslen - 1);
+	res[reslen-1] = 0;
+  }
+
+  return res;
 }
 
 /*
@@ -75,7 +99,7 @@ char *esc_key()
 	return(buf);
   }
 #if defined(_COHERENT) || defined(i386) || defined(__i386__)
-  sprintf(buf, "ALT-");
+  sprintf(buf, "ESC,");
 #else
   sprintf(buf, "Meta-");
 #endif
@@ -90,6 +114,37 @@ int dummy;
   longjmp(albuf, 1);
 }
 
+#ifdef USE_SOCKET
+/*
+ * If portfd is a socket, we try to (re)connect
+ */
+void term_socket_connect()
+{
+
+  if (!portfd_is_socket || portfd_is_connected)
+    return;
+
+  if ((portfd = socket(AF_UNIX, SOCK_STREAM, 0)) == -1)
+    return;
+
+  if (connect(portfd, (struct sockaddr *)&portfd_sock_addr,
+              sizeof(portfd_sock_addr)) == -1)
+    term_socket_close();
+  else
+    portfd_is_connected = 1;
+}
+
+/*
+ * Close the connection if the socket delivers "eof" (read returns 0)
+ */
+void term_socket_close()
+{
+  close(portfd);
+  portfd_is_connected = 0;
+  portfd = -1;
+}
+#endif /* USE_SOCKET */
+
 /*
  * Open the terminal.
  */
@@ -101,7 +156,7 @@ int doinit;
   int fd, n = 0;
   int pid;
   int mask;
-#if defined(__linux__) || (defined(BSD) && (BSD >= 199306))
+#ifdef HAVE_ERRNO_H
   int s_errno;
 #endif
 
@@ -109,12 +164,22 @@ int doinit;
   set_privs();
 
   /* First see if the lock file directory is present. */
-  if (P_LOCK[0] && stat(P_LOCK, &stt) == 0)
-  	snprintf(lockfile, sizeof(lockfile), "%s/LCK..%s", P_LOCK, mbasename(dial_tty));
-  else
-	lockfile[0] = 0;
+  if (P_LOCK[0] && stat(P_LOCK, &stt) == 0) {
 
-  if (doinit >= 0 && lockfile[0] && (fd = open(lockfile, O_RDONLY)) >= 0) {
+#ifdef SVR4_LOCKS
+    stat(dial_tty, &stt);
+    sprintf(lockfile, "%s/LK.%03d.%03d.%03d", P_LOCK, major(stt.st_dev), major(stt.st_rdev), minor(stt.st_rdev));
+
+#else /* SVR4_LOCKS */
+    snprintf(lockfile, sizeof(lockfile), "%s/LCK..%s", P_LOCK, mbasename(dial_tty, buf, sizeof(buf)));
+
+#endif /* SVR4_LOCKS */
+
+  }
+  else
+    lockfile[0] = 0;
+
+  if (doinit > 0 && lockfile[0] && (fd = open(lockfile, O_RDONLY)) >= 0) {
 	n = read(fd, buf, 127);
 	close(fd);
 	if (n > 0) {
@@ -143,60 +208,7 @@ int doinit;
 	}
   }
 
-  /* Run a special program to disable callin if needed. */
-  if (doinit > 0 && P_CALLOUT[0]) {
-	if(fastsystem(P_CALLOUT, CNULL, CNULL, CNULL) < 0) {
-  		if (stdwin != NIL_WIN) wclose(stdwin, 1);
-  		fprintf(stderr, _("Could not setup for dial out.\n"));
-  		if (lockfile[0]) unlink(lockfile);
-		drop_privs();
-		return(-1);
-  	}
-  }
-
-  /* Now open the tty device. */
-  if (setjmp(albuf) == 0) {
-	portfd = -1;
-	signal(SIGALRM, get_alrm);
-	alarm(2);
-#if defined(O_NDELAY) && defined(F_SETFL)
-	portfd = open(dial_tty, O_RDWR|O_NDELAY);
-	if (portfd >= 0){
-		/* Cancel the O_NDELAY flag. */
-		n = fcntl(portfd, F_GETFL, 0);
-		(void) fcntl(portfd, F_SETFL, n & ~O_NDELAY);
-	}
-#else
-	portfd = open(dial_tty, O_RDWR);
-#endif
-	if (portfd >= 0) {
-		if (doinit >= 0) m_savestate(portfd);
-		port_init();
-	}
-  }
-#if defined(__linux__) || (defined(BSD) && (BSD >= 199306))
-  s_errno = errno;
-#endif
-  alarm(0);
-  signal(SIGALRM, SIG_IGN);
-  if (portfd < 0) {
-	if (doinit >= 0) {
-  		if (stdwin != NIL_WIN) wclose(stdwin, 1);
-#if defined(__linux__) || (defined(BSD) && (BSD >= 199306))
-		fprintf(stderr, _("minicom: cannot open %s: %s\n"),
-			dial_tty, strerror(s_errno));
-#else
-  		fprintf(stderr, _("minicom: cannot open %s. Sorry.\n"), dial_tty);
-#endif
-		drop_privs();
-		return(-1);
-	}
-	werror(_("Cannot open %s!"), dial_tty);
-	drop_privs();
-	return(-1);
-  }
-
-  if (doinit >= 0 && lockfile[0]) {
+  if (doinit > 0 && lockfile[0]) {
   	/* Create lockfile compatible with UUCP-1.2 */
 	mask = umask(022);
 #ifdef _COH3
@@ -216,6 +228,78 @@ int doinit;
   	close(fd);
   }
 
+  /* Run a special program to disable callin if needed. */
+  if (doinit > 0 && P_CALLOUT[0]) {
+	if(fastsystem(P_CALLOUT, CNULL, CNULL, CNULL) < 0) {
+  		if (stdwin != NIL_WIN) wclose(stdwin, 1);
+  		fprintf(stderr, _("Could not setup for dial out.\n"));
+  		if (lockfile[0]) unlink(lockfile);
+		drop_privs();
+		return(-1);
+  	}
+  }
+
+  /* Now open the tty device. */
+  if (setjmp(albuf) == 0) {
+	portfd = -1;
+	signal(SIGALRM, get_alrm);
+	alarm(4);
+#if USE_SOCKET
+#define SOCKET_PREFIX "unix#"
+	portfd_is_socket = portfd_is_connected = 0;
+	if (strncmp(dial_tty, SOCKET_PREFIX, strlen(SOCKET_PREFIX)) == 0) {
+		portfd_is_socket = 1;
+
+		portfd_sock_addr.sun_family = AF_UNIX;
+		strncpy(portfd_sock_addr.sun_path,
+		        dial_tty + strlen(SOCKET_PREFIX),
+			sizeof(portfd_sock_addr.sun_path)-1);
+		portfd_sock_addr.sun_path[sizeof(portfd_sock_addr.sun_path)-1] = 0;
+		term_socket_connect();
+	}
+#endif /* USE_SOCKET */
+	if (!portfd_is_socket) {
+#if defined(O_NDELAY) && defined(F_SETFL)
+		portfd = open(dial_tty, O_RDWR|O_NDELAY|O_NOCTTY);
+		if (portfd >= 0) {
+			/* Cancel the O_NDELAY flag. */
+			n = fcntl(portfd, F_GETFL, 0);
+			(void) fcntl(portfd, F_SETFL, n & ~O_NDELAY);
+		}
+#else
+		if (portfd < 0)
+			portfd = open(dial_tty, O_RDWR|O_NOCTTY);
+#endif
+	}
+	if (portfd >= 0) {
+		if (doinit > 0) m_savestate(portfd);
+		port_init();
+	}
+  }
+#ifdef HAVE_ERRNO_H
+  s_errno = errno;
+#endif
+  alarm(0);
+  signal(SIGALRM, SIG_IGN);
+  if (portfd < 0 && !portfd_is_socket) {
+	if (doinit > 0) {
+  		if (stdwin != NIL_WIN) wclose(stdwin, 1);
+#ifdef HAVE_ERRNO_H
+		fprintf(stderr, _("minicom: cannot open %s: %s\n"),
+			dial_tty, strerror(s_errno));
+#else
+  		fprintf(stderr, _("minicom: cannot open %s. Sorry.\n"), dial_tty);
+#endif
+		if (lockfile[0]) unlink(lockfile);
+		drop_privs();
+		return(-1);
+	}
+	if (lockfile[0]) unlink(lockfile);
+	werror(_("Cannot open %s!"), dial_tty);
+	drop_privs();
+	return(-1);
+  }
+
   /* Remember owner of port */
   stat(dial_tty, &stt);
   portuid = stt.st_uid;
@@ -318,6 +402,7 @@ int do_init;
   }
 
   us->autocr = 0;
+  us->wrap = wrapln;
 
   terminal = type;
   lines = LINES - (st != NIL_WIN);
@@ -326,7 +411,7 @@ int do_init;
   /* Install and reset the terminal emulator. */
   if (do_init) {
   	vt_install(do_output, kb_handler, us);
-	vt_init(type, tfcolor, tbcolor, type != VT100, 0);
+	vt_init(type, tfcolor, tbcolor, us->wrap, 0);
   } else
 	vt_pinit(us, -1, -1);
 
@@ -350,10 +435,14 @@ void mode_status()
 {
   if (st) { /* if swich off status line - NOT print !!! (vlk@st.simbirsk.su) */
     wlocate(st, 20, 0);
-    if (P_SHOWSPD[0] == 'l')
-      wprintf(st, "%6ld %s%s1", linespd, P_BITS, P_PARITY);
-    else
-      wprintf(st, "%6.6s %s%s1", P_BAUDRATE, P_BITS, P_PARITY);
+    if (portfd_is_socket) {
+      wprintf(st, "unix-socket");
+    } else {
+      if (P_SHOWSPD[0] == 'l')
+	wprintf(st, "%6ld %s%s%s", linespd, P_BITS, P_PARITY, P_STOPB);
+      else
+	wprintf(st, "%6.6s %s%s%s", P_BAUDRATE, P_BITS, P_PARITY, P_STOPB);
+    }
     ret_csr();
   }
 }
@@ -365,6 +454,8 @@ void mode_status()
  */
 void time_status()
 {
+  if (!st || disable_online_time)
+    return;
   wlocate(st, 63, 0);
   if (online < 0)
   	wprintf(st, " %12.12s ", P_HASDCD[0] == 'Y' ? _("Offline") : _("OFFLINE"));
@@ -394,7 +485,7 @@ static void updtime()
 {
 
   if (old_online == online) return;
-  if ((old_online >= 0) && (online < 0)) {
+  if ((P_LOGCONN[0] == 'Y') && (old_online >= 0) && (online < 0)) {
     do_log(_("Gone offline (%ld:%02ld:%02ld)"),
       old_online / 3600, (old_online / 60) % 60, old_online % 60);
   }
@@ -463,8 +554,9 @@ void show_status()
 {
   st->direct = 0;
   wlocate(st, 0, 0);
-  wprintf(st, _(" %7.7sZ for help \263           \263     \263 Minicom %-6.6s \263       \263 "),
-  	esc_key(), ST_VERSION);
+  wprintf(st,
+	  _(" %7.7sZ for help |           |     | Minicom %-6.6s |       | "),
+	  esc_key(), VERSION);
   mode_status();
   time_status();
   curs_status();
@@ -490,7 +582,7 @@ char *s;
   if (st == NIL_WIN) return;
   wlocate(st, 39, 0);
   if (*s == 0)
-  	wprintf(st, "Minicom %-6.6s", ST_VERSION);
+  	wprintf(st, "Minicom %-6.6s", VERSION);
   else
       	wprintf(st, "script %-7.7s", s);
   ret_csr();
@@ -562,6 +654,8 @@ dirty_goto:
 		wclose(stdwin, 0);
                 if (win_init(tfcolor, tbcolor, XA_NORMAL) < 0)
 			leave(_("Could not re-initialize window system."));
+  		/* Set the terminal modes */
+  		(void) setcbreak(2); /* Raw, no echo */
 		init_emul(terminal, 0);
 #else
 		werror(_("Resize not supported, screen may be messed up!"));
@@ -571,7 +665,7 @@ dirty_goto:
 	timer_update();
 
 	/* Check for I/O or timer. */
-	x = check_io(portfd, 0, 1000, buf, &blen);
+	x = check_io(portfd_connected, 0, 1000, buf, &blen);
 
 	/*  Send data from the modem to the screen. */
   	if ((x & 1) == 1) {
@@ -605,10 +699,11 @@ dirty_goto:
 		if (c < 0) c += 256; /* XXX - shouldn't happen */
 
 		/* Was this a command key? */
+		if (
 #ifndef RH_FIX
-		if ((escape == 128 && c > 224 && c < 252) ||
+		    (escape == 128 && c > 224 && c < 252) ||
 #else   /* filipg 8/22/97: needed to recognize Fkeys in RedHat 4.1 */
-		if ((escape == 128 && c > 128 && c < 256) ||
+		    (escape == 128 && c > 128 && c < 256) ||
 #endif /* RH_FIX */
 		    (escape != 27 && c == escape) || 
 		    (c > K_META)) {
@@ -616,13 +711,14 @@ dirty_goto:
 			/* Stop keyserv process if we have it. */
   			keyboard(KSTOP, 0);
 
-  			/* Restore keyboard modes */
-  			(void) setcbreak(1); /* Cbreak, no echo */
-
   			/* Show status line temporarily */
   			showtemp();
   			if (c == escape) /* CTRL A */
 				c = keyboard(KGETKEY, 0);
+
+  			/* Restore keyboard modes */
+  			(void) setcbreak(1); /* Cbreak, no echo */
+
 			if (c > K_META) c -= K_META;
   			if (c > 128) c -= 128;
   			if (c > ' ') {
