@@ -19,13 +19,21 @@
  *				command line
  * jl  09.07.98 added option -S to start a script at startup
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID(PKG_VER "$Id: minicom.c,v 1.10 2003/05/16 20:33:19 al-guest Exp $")
+
+#include <getopt.h>
 
 #define EXTERN
 #include "port.h"
 #include "minicom.h"
-#include "patchlevel.h"
 #include "intl.h"
 
+
 #define RESET 1
 #define NORESET 2
 
@@ -57,8 +65,8 @@ static char *c7[] = { N_("   Yes  "), N_("   No   "), CNULL };
 /* Initialize modem port. */
 void port_init()
 {
-  m_setparms(portfd, P_BAUDRATE, P_PARITY, P_BITS, P_HASRTS[0] == 'Y',
-	P_HASXON[0] == 'Y');
+  m_setparms(portfd, P_BAUDRATE, P_PARITY, P_BITS, P_STOPB,
+	     P_HASRTS[0] == 'Y', P_HASXON[0] == 'Y');
 }
 
 static void do_hang(askit)
@@ -90,11 +98,12 @@ int sig;
  */
 #ifdef SIGTSTP
 /*ARGSUSED*/
-static void shjump(sig)
-int sig;
+static void shjump(dummy /* __attribute__((unused)) */)
+int dummy;
 {
   extern int use_status;
 
+  if (dummy) {}; /* avoid compiler warning, should be optimized away... */
   wleave();
   signal(SIGTSTP, SIG_DFL);
   fputs(_("Suspended. Type \"fg\" to resume.\n"),stdout);
@@ -105,7 +114,7 @@ int sig;
 }
 #else
 /*ARGSUSED*/
-static void shjump(dummy)
+static void shjump(dummy /* __attribute__((unused)) */)
 int dummy;
 {
   extern int use_status;
@@ -115,6 +124,7 @@ int dummy;
   int status;
   int f;
 
+  if (dummy) {}; /* avoid compiler warning, should be optimized away... */
   sh = getenv("SHELL");
   if (sh == CNULL) {
   	werror(_("SHELL variable not set"));
@@ -215,7 +225,7 @@ int	case_matters;
 	tmp_e = getline(w, y++);
 
   	/* First we "accumulate" the line into a variable */
-	wdrawelm_var(w, f, tmp_e, tmp_line);
+	wdrawelm_var(w, tmp_e, tmp_line);
 
 	/* Does it have what we want? */
 	if (strlen(look)>1 && strlen(tmp_line)>1) {
@@ -235,9 +245,8 @@ int	case_matters;
  * Search history - main function that started the C-code blasphemy :-)
  * This function doesn't care about case/case-less status...
  */
-void searchhist(w_orig, w_hist, r, str)
-WIN *w_orig,*w_hist;
-int r;
+void searchhist(w_hist, str)
+WIN *w_hist;
 char *str;
 {
   int y;
@@ -318,7 +327,7 @@ int	case_matters;	/* guess... */
 	 * First we "accumulate" the line into a variable.
 	 * To see 'why', see what an 'ELM' structure looks like!
 	 */
-	wdrawelm_var(w, next_line, tmp_e, tmp_line);
+	wdrawelm_var(w, tmp_e, tmp_line);
 
 	/* Does it have what we want? */
 	if (strlen(tmp_line) > 1 && strlen(look) > 1)
@@ -408,7 +417,7 @@ int start,end;
 	vt_send('>');
 	vt_send(' ');
 	tmp_e = getline(w, y);
-	wdrawelm_var(w, 0 /* dummy? */, tmp_e, tmp_line);
+	wdrawelm_var(w, tmp_e, tmp_line);
 	tmp_line[w->xs]=0;
 	for (x=w->xs-1; x>=0; x--){
 		if (tmp_line[x] <= ' ') tmp_line[x]=0;
@@ -435,7 +444,7 @@ static void scrollback()
   int citemode = 0;
   int cite_ystart = 1000000,
       cite_yend = -1,
-      cite_y;
+      cite_y = 0;
   int inverse;
   int loop = 1;
 
@@ -467,7 +476,7 @@ static void scrollback()
    */
   strcpy(hline0, _("HISTORY: U=Up D=Down F=PgDn B=PgUp s=Srch S=CaseLess N=Next C=Cite ESC=Exit "));
 #else
-  strcpy(hline0, "  SCROLL MODE    U=up D=down F=page-forward B=page-backward C=Cite ESC=exit ");
+  strcpy(hline0, _("  SCROLL MODE    U=up D=down F=page-forward B=page-backward C=Cite ESC=exit "));
 #endif /*_HIST_SEARCH*/
 
   if (b_st->xs < 127)
@@ -517,7 +526,7 @@ static void scrollback()
 			case_matters=1; /* case-importance, ie. DOES */
 
 		/* open up new search window... */
-		searchhist(us, b_us, 0, look_for);
+		searchhist(b_us, look_for);
 		/* must redraw status line... */
   		wlocate(b_st, 0, 0); /* move back to column 0! */
   		wprintf(b_st, hline); /* and show the above-defined hline */
@@ -594,7 +603,7 @@ static void scrollback()
 			if (strlen(look_for) > 1)
 			{
 			  /* quick scan for pattern match */
-			  wdrawelm_var(b_us, 0, tmp_e, tmp_line);
+			  wdrawelm_var(b_us, tmp_e, tmp_line);
 			  inverse = (strlen(tmp_line)>1 &&
 			    StrStr(tmp_line, look_for, case_matters));
 			}
@@ -647,7 +656,7 @@ static void scrollback()
 			if (strlen(look_for) > 1)
 			{
 				/* quick scan for pattern match */
-        			wdrawelm_var(b_us, 0, tmp_e, tmp_line);
+        			wdrawelm_var(b_us, tmp_e, tmp_line);
 				inverse = (strlen(tmp_line)>1 &&
 				  StrStr(tmp_line, look_for, case_matters));
 			}
@@ -816,17 +825,13 @@ char **s;
   return(begin);
 }
 
-static char *bletch = 
-  N_("Usage: minicom [-somlz8] [-c on] [-a on] [-t TERM] [-S scriptname] [-d entry]\n\t[-p ttyp] [-C capturefile] [configuration]\n");
-
 static void usage(env_args, optind, mc)
 int env_args, optind;
 char *mc;
 {
   if (env_args >= optind && mc)
-  	fprintf(stderr, _("Wrong option in environment MINICOM=%s\n"), mc);
-  fputs(_(bletch), stderr);
-  fputs(_("Type \"minicom -h\" for help.\n"), stderr);
+	 fprintf(stderr, _("Wrong option in environment MINICOM=\"%s\"\n"), mc);
+  fprintf(stderr, _("Type \"minicom %s\" for help.\n"), "--help");
   exit(1);
 }
 
@@ -835,40 +840,34 @@ static void helpthem()
 {
   char *mc = getenv("MINICOM");
 
-  printf("\n%s", Version);
-#ifdef __DATE__
-  printf(_(" (compiled %s)"), __DATE__);
-#endif /*__DATE_*/
-  printf(_("(c) Miquel van Smoorenburg\n\n%s\n"), _(bletch));
-  fputs(_("  -s             : enter setup mode (only as root)\n"),stdout);
-  fputs(_("  -o             : do not initialize modem & lockfiles at startup\n"), stdout);
-  fputs(_("  -m             : use meta or alt key for commands\n"), stdout);
-  fputs(_("  -l             : literal ; assume screen uses the IBM-PC character set\n"), stdout);
-  fputs(_("  -L             : Ditto, but assume screen uses ISO8859\n"), stdout); 
-  fputs(_("  -z             : try to use terminal's status line\n"), stdout);
-  fputs(_("  -8             : 8bit clean mode (for Japanese, etc)\n"), stdout);
-  fputs(_("  -c [on | off]  : ANSI style color usage on or off\n"), stdout);
-  fputs(_("  -a [on | off]  : use reverse or highlight attributes on or off\n"), stdout);
-  fputs(_("  -t term        : override TERM environment variable\n"), stdout);
-  fputs(_("  -S scriptname  : run script at startup\n"), stdout);
-  fputs(_("  -d entry       : dial `entry' from the dialing directory\n"), stdout);
-  fputs(_("  -p ttyp..      : connect to pseudo terminal\n"), stdout);
-  fputs(_("  -C filename    : start capturing with the file name\n"), stdout);
-  fputs(_("  configuration  : configuration file to use\n\n"), stdout);
-  fputs(_("These options can also be specified in the MINICOM environment variable.\n"), stdout);
-  printf(_("This variable is currently %s%s.\n"), mc ? _("set to ") : _("unset"),
-	mc ? mc : "");
-  fputs(_("The LIBDIR to find the configuration files and the\n"), stdout);
-  printf(_("access file minicom.users is compiled as %s.\n\n"), LIBDIR);
-
-#if 0  /* More than 24 lines.. */
-  printf("\
-This program is free software; you can redistribute it and/or\n\
-modify it under the terms of the GNU General Public License\n\
-as published by the Free Software Foundation; either version\n\
-2 of the License, or (at your option) any later version.\n\n");
-#endif
-
+  printf(_("Usage: %s [OPTION]... [configuration]\n"), PACKAGE);
+  printf(_("A terminal program for Linux and other unix-like systems.\n\n"));
+  printf(_("  -s, --setup            : enter setup mode (only as root)\n"));
+  printf(_("  -o, --noinit           : do not initialize modem & lockfiles at startup\n"));
+  printf(_("  -m, --metakey          : use meta or alt key for commands\n"));
+  printf(_("  -M, --metakey8         : use 8bit meta key for commands\n"));
+  printf(_("  -l, --ansi             : literal; assume screen uses the IBM-PC character set\n"));
+  printf(_("  -L, --iso              : Ditto, but assume screen uses ISO8859\n")); 
+  printf(_("  -w, --wrap             : Linewrap on\n"));
+  printf(_("  -z, --statline         : try to use terminal's status line\n"));
+  printf(_("  -8, --8bit             : 8bit clean mode (for Japanese, etc)\n"));
+  printf(_("  -c, --color=on/off     : ANSI style color usage on or off\n"));
+  printf(_("  -a, --attrib=on/off    : use reverse or highlight attributes on or off\n"));
+  printf(_("  -t, --term=TERM        : override TERM environment variable\n"));
+  printf(_("  -S, --script=SCRIPT    : run SCRIPT at startup\n"));
+  printf(_("  -d, --dial=ENTRY       : dial ENTRY from the dialing directory\n"));
+  printf(_("  -p, --ptty=TTYP        : connect to pseudo terminal\n"));
+  printf(_("  -C, --capturefile=FILE : start capturing to FILE\n"));
+  printf(_("  -T, --disabletime      : disable display of online time\n"));
+  printf(_("  -v, --version          : output version information and exit\n"));
+  printf(_("  configuration          : configuration file to use\n\n"));
+  printf(_("These options can also be specified in the MINICOM environment variable.\n"));
+  printf(_("This variable is currently %s"), mc ? _("set to ") : _("unset.\n"));
+  if (mc)
+    printf("\"%s\".\n", mc);
+  printf(_("The configuration directory for the access file and the configurations\n"));
+  printf(_("is compiled to %s.\n\n"), CONFDIR);
+  printf(_("Report bugs to <minicom-devel@lists.alioth.debian.org>.\n"));
 }
 
 int main(argc, argv)
@@ -898,10 +897,34 @@ char **argv;
   char pseudo[64];
 /*  char* console_encoding = getenv ("LC_CTYPE"); */
 
-#ifdef _I18N_
-  bindtextdomain("minicom", "/usr/share/locale");
-  textdomain("minicom");
-#endif
+  static struct option long_options[] =
+  {
+	  { "setup", no_argument, NULL, 's' },
+	  { "help", no_argument, NULL, 'h' },
+	  { "ptty", required_argument, NULL, 'p' },
+	  { "metakey", no_argument, NULL, 'm' },
+	  { "metakey8", no_argument, NULL, 'M' },
+	  { "ansi", no_argument, NULL, 'l' },
+	  { "iso", no_argument, NULL, 'L' },
+	  { "term", required_argument, NULL, 't' },
+	  { "noinit", no_argument, NULL, 'o' },
+	  { "color", required_argument, NULL, 'c' },
+	  { "attrib", required_argument, NULL, 'a' },
+	  { "dial", required_argument, NULL, 'd' },
+	  { "statline", no_argument, NULL, 'z' },
+	  { "capturefile", required_argument, NULL, 'C' },
+	  { "script", required_argument, NULL, 'S' },
+	  { "8bit", no_argument, NULL, '8' },
+	  { "version", no_argument, NULL, 'v' },
+	  { "wrap", no_argument, NULL, 'w' },
+	  { "disabletime", no_argument, NULL, 'T' },
+	  { NULL, 0, NULL, 0 }
+  };
+
+  /* initialize locale support */
+  setlocale(LC_ALL, "");
+  bindtextdomain(PACKAGE, LOCALEDIR);
+  textdomain(PACKAGE);
 
   /* Initialize global variables */
   portfd = -1;
@@ -912,7 +935,9 @@ char **argv;
   stdattr = XA_NORMAL;
   us = NIL_WIN;
   addlf = 0;
-#ifdef _SELECT
+  wrapln = 0;
+  disable_online_time = 0;
+#ifdef HAVE_SELECT
   local_echo = 0;
 #endif /*SELECT*/
   strcpy(capname, "minicom.cap");
@@ -961,10 +986,27 @@ char **argv;
 
 /* kubota@debian.or.jp 12/07/1998 */
   {
-	char *lang = getenv("LANG");
-	if (lang!=NULL && (!strncmp(lang,"ja",2) || !strncmp(lang,"ko",2))) {
-		args[argk++] = "-8";
+    /* Boah, a hack .... should we switch to 8bit for all
+     * and supply a 7bit option? Adam */
+    char *v[] = { "LANG", "LC_ALL" };
+    char *l[] = { "ja", "ko", "ru" };
+    unsigned int i;
+    int done = 0;
+
+    for (i = 0; !done && i < sizeof(v)/sizeof(*v); i++) {
+      char *lang = getenv(v[i]);
+      if (lang != NULL) {
+	unsigned int j = 0;
+	for (; j < sizeof(l)/sizeof(*l); j++) {
+	  printf("%s/%s\n", v[i], l[j]);
+	  if (!strncmp(lang, l[j], strlen(l[j]))) {
+	    args[argk++] = "-8";
+	    done = 1;
+	    break;
+	  }
 	}
+      }
+    }
   }
 
 /* MARK updated 02/17/95 default history buffer size */
@@ -996,11 +1038,25 @@ char **argv;
 
   do {
 	/* Process options with getopt */
-	while((c = getopt(argk, args, "8zhlLsomMbc:a:t:d:p:C:S:")) != EOF)
+	while((c = getopt_long(argk, args, "v8zhlLsomMbwTc:a:t:d:p:C:S:",
+					long_options, NULL)) != EOF)
 	  switch(c) {
+		case 'v':
+			printf(_("%s version %s"), PACKAGE, VERSION);
+#ifdef __DATE__
+			printf(_(" (compiled %s)"), __DATE__);
+#endif
+			printf("\n");
+			printf(_("Copyright (C) Miquel van Smoorenburg.\n\n"));
+			printf("This program is free software; you can redistribute it and/or\n"
+			       "modify it under the terms of the GNU General Public License\n"
+			       "as published by the Free Software Foundation; either version\n"
+			       "2 of the License, or (at your option) any later version.\n\n");
+			exit(1);
+			break;
   		case 's': /* setup */
   			if (real_uid != 0 && real_uid != eff_uid) {
-		fputs(_("minicom: -s switch needs root privilige\n"), stderr);
+				fprintf(stderr, _("minicom: -s switch needs root privilige\n"));
 				exit(1);
 			}
   			dosetup = 1;
@@ -1012,10 +1068,13 @@ char **argv;
 		case 'p': /* Pseudo terminal to use. */
 			if (strncmp(optarg, "/dev/", 5) == 0)
 				optarg += 5;
-			if (strncmp(optarg, "tty", 3) != 0 ||
-			    !strchr("pqrstuvwxyz", optarg[3])) {
-				fputs(
-				 _("minicom: argument to -p must be a pty\n"), stderr);
+			if (((strncmp(optarg, "tty", 3) != 0)
+					/* /dev/pts support --misiek. */
+					&& (strncmp(optarg, "pts", 3) != 0)
+					/* /dev/pty support --jl. */
+					&& (strncmp(optarg, "pty", 3) != 0))
+					|| !strchr("pqrstuvwxyz/", optarg[3])) {
+				fprintf(stderr, _("minicom: argument to -p must be a pty\n"));
 				exit(1);
 			}
 			snprintf(pseudo, sizeof(pseudo), "/dev/%s", optarg);
@@ -1040,7 +1099,7 @@ char **argv;
 			break;
 		case 't': /* Terminal type */
 			strncpy(termtype, optarg, sizeof(termtype));
-#ifdef __linux__
+#ifdef __GLIBC__
 			/* Bug in older libc's (< 4.5.26 I think) */
 			if ((s = getenv("TERMCAP")) != NULL && *s != '/')
 				unsetenv("TERMCAP");
@@ -1095,7 +1154,13 @@ char **argv;
 			vt_set(-1, -1, (FILE*)NULL, -1, -1, -1, -1, 1);
 			screen_ibmpc++; screen_iso++;
 			break;
-  		default:
+		case 'w': /* Linewrap on */
+			wrapln = 1;
+			break;
+		case 'T': /* disable online time */
+			disable_online_time = 1;
+			break;
+		default:
   			usage(env_args, optind, mc);
   			break;
   	}
@@ -1107,19 +1172,19 @@ char **argv;
     /* Loop again if more options */
   } while(optind < argk);
 
-/*
- * if (real_uid == 0 && dosetup == 0) {
- *	fprintf(stderr, "%s%s%s",
- *  "minicom: WARNING: please don't run minicom as root when not maintaining\n",
- *  "                  it (with the -s switch) since all changes to the\n",
- *  "                  configuration will be GLOBAL !.\n");
- *	sleep(5);
- * }
-*/
+#ifdef SVR4_LOCKS
+  if (real_uid == 0 && dosetup == 0) {
+    fprintf(stderr, "%s",
+_("minicom: WARNING: please don't run minicom as root when not maintaining\n"
+  "                  it (with the -s switch) since all changes to the\n"
+  "                  configuration will be GLOBAL !.\n"));
+ 	sleep(5);
+  }
+#endif
 
   /* Avoid fraude ! */	
   for(s = use_port; *s; s++) if (*s == '/') *s = '_';
-  snprintf(parfile, sizeof(parfile), "%s/minirc.%s", LIBDIR, use_port);
+  snprintf(parfile, sizeof(parfile), "%s/minirc.%s", CONFDIR, use_port);
 
   /* Get password file information of this user. */
   if ((pwd = getpwuid(real_uid)) == (struct passwd *)0) {
@@ -1139,7 +1204,7 @@ char **argv;
 
   /* Check this user in the USERFILE */
   if (real_uid != 0 && real_uid != eff_uid) {
-  	snprintf(userfile, sizeof(userfile), "%s/minicom.users", LIBDIR);
+  	snprintf(userfile, sizeof(userfile), "%s/minicom.users", CONFDIR);
 	if ((fp = fopen(userfile, "r")) != (FILE *)0) {
 		while(fgets(buf, 70, fp) != CNULL && !userok) {
 			/* Read first word */
@@ -1174,6 +1239,7 @@ char **argv;
 
   read_parms();
   num_hist_lines = atoi(P_HISTSIZE);
+  strcpy(logfname,P_LOGFNAME);
 
   stdwin = NIL_WIN; /* It better be! */
 
@@ -1216,22 +1282,8 @@ char **argv;
   }
 
   /* Signal handling */
-  for(c = 1; c <= _NSIG; c++) {
-#ifdef SIGCLD /* Better not mess with those */
-	if (c == SIGCLD) continue;
-#endif
-#ifdef SIGCHLD
-	if (c == SIGCHLD) continue;
-#endif
-#ifdef SIGCONT
-	if (c == SIGCONT) continue;
-#endif
-	signal(c, hangsig);
-  }
-
-#if 0 /* Is this OK? */
-  signal(SIGHUP, SIG_IGN);
-#endif
+  signal(SIGTERM, hangsig);
+  signal(SIGHUP, hangsig);
   signal(SIGINT, SIG_IGN);
   signal(SIGQUIT, SIG_IGN);
   signal(SIGPIPE, SIG_IGN);
@@ -1283,7 +1335,7 @@ char **argv;
  
   if (doinit) modeminit();
  
-  wprintf(us, "\n%s\r\n", _(CR_VERSION));
+  wprintf(us, "\n%s %s\r\n", _("Welcome to minicom"), VERSION);
   wprintf(us, "\n%s: %s%s%s%s%s\r\n", _("OPTIONS"),
 	  CR_OPTION1,CR_OPTION2,CR_OPTION3,CR_OPTION4,CR_OPTION5);
 #if defined (__DATE__) && defined (__TIME__)
@@ -1310,15 +1362,15 @@ dirty_goto:
 			vt_set(addlf, -1, NULL, -1, -1, -1, -1, -1);
 			s = addlf ?
 			  _("Add linefeed ON") : _("Add linefeed OFF");
-			werror(s);
+			werror("%s", s);
 			break;
-#if _SELECT
+#ifdef HAVE_SELECT
 		case 'e': /* Local echo on/off. */
 			local_echo = !local_echo;
 			vt_set(-1, -1, NULL, -1, -1, local_echo, -1 ,-1);
 			s = local_echo ?
 			  _("Local echo ON") : _("Local echo OFF");
-			werror(s);
+			werror("%s", s);
 			break;
 #endif
 		case 'z': /* Help */
@@ -1411,7 +1463,7 @@ dirty_goto:
 			vt_set(addlf, -1, capfp, docap, -1, -1, -1, -1);
 			break;
 		case 'p': /* Set parameters */
-			get_bbp(P_BAUDRATE, P_BITS, P_PARITY, 0);
+			get_bbp(P_BAUDRATE, P_BITS, P_PARITY, P_STOPB, 0);
 			port_init();
 			if (st != NIL_WIN) mode_status();
 			quit = 0;
@@ -1433,7 +1485,7 @@ dirty_goto:
 			c = (!us->wrap);
 			vt_set(addlf, c, capfp, docap, -1, -1, -1, -1);
 			s = c ? _("Linewrap ON") : _("Linewrap OFF");
-			werror(s);
+			werror("%s", s);
 			break;
 		case 'o': /* Configure Minicom */
 			(void) config(0);
@@ -1464,8 +1516,8 @@ dirty_goto:
   if (quit != NORESET)
 	m_restorestate(portfd);
   else {
-        if (online > 0)
-	  do_log(_("Quit without reset while online."));
+        if (P_LOGCONN[0] == 'Y' && online > 0)
+	  do_log("%s", _("Quit without reset while online."));
 	m_hupcl(portfd, 0);
   }
   if (capfp != (FILE *)0) fclose(capfp);
