@@ -1,6 +1,8 @@
 /*
  * minicom.h	Constants, defaults, globals etc.
  *
+ * 		$Id: minicom.h,v 1.6 2003/04/26 07:31:06 al-guest Exp $
+ *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
  *
@@ -25,6 +27,38 @@
 #include "window.h"
 #include "keyboard.h"
 #include "vt100.h"
+#include "libport.h"
+
+#ifdef USE_SOCKET
+#include <sys/socket.h>
+#include <sys/un.h>
+#endif
+
+#ifdef _HISTORY
+#define CR_OPTION1 "History Buffer, "
+#else
+#define CR_OPTION1 ""
+#endif /*HISTORY*/
+#ifdef _HAVE_MACROS
+#define CR_OPTION2 "F-key Macros, "
+#else
+#define CR_OPTION2 ""
+#endif /*HAVE_MACROS*/
+#ifdef _RH_FIX
+#define CR_OPTION3 "RedHat fix, "
+#else
+#define CR_OPTION3 ""
+#endif /*RH_FIX*/
+#ifdef _SEARCH_HISTORY
+#define CR_OPTION4 "Search History Buffer, "
+#else
+#define CR_OPTION4 ""
+#endif /*SEARCH_HISTORY*/
+#ifdef ENABLE_NLS
+#define CR_OPTION5 "I18n "
+#else
+#define CR_OPTION5 ""
+#endif
 
 /*
  * kubota@debian.or.jp 08/08/98
@@ -65,8 +99,10 @@ EXTERN int cursormode;	/* Mode of cursor (arrow) keys */
 EXTERN int docap;	/* Capture data to capture file */
 EXTERN FILE *capfp;	/* File to capture to */
 EXTERN int addlf;	/* Add LF after CR */
+EXTERN int wrapln;	/* Linewrap default */
 EXTERN int tempst;	/* Status line is temporary */
 EXTERN int escape;	/* Escape code. */
+EXTERN int disable_online_time; /* disable online time display */
 
 EXTERN char lockfile[128]; /* UUCP lock file of terminal */
 EXTERN char homedir[256];  /* Home directory of user */
@@ -92,6 +128,18 @@ EXTERN char *dial_number;   /* Number we've dialed. */
 EXTERN char *dial_user;     /* Our username there */
 EXTERN char *dial_pass;     /* Our password */
 
+#ifdef USE_SOCKET
+EXTERN int portfd_is_socket;	/* File descriptor is a unix socket */
+EXTERN int portfd_is_connected;	/* 1 if the socket is connected */
+EXTERN struct sockaddr_un portfd_sock_addr;	/* the unix socket address */
+#define portfd_connected ((portfd_is_socket && !portfd_is_connected) \
+                           ? -1 : portfd)
+#else
+#define portfd_connected portfd
+#define portfd_is_socket 0
+#define portfd_is_connected 0
+#endif /* USE_SOCKET */
+
 /*
  * fmg 8/22/97
  * Search pattern can be THIS long (x characters)
@@ -123,7 +171,7 @@ _PROTO(int Jcolor, ( char * ));
 EXTERN int size_changed;    /* Window size has changed */
 extern char *Version;	    /* Minicom verson */
 
-#if _SELECT
+#ifdef HAVE_SELECT
 EXTERN int local_echo;      /* Local echo on/off. */
 #endif
 
@@ -165,6 +213,7 @@ _PROTO(void dialdir, ( void ));
 /*      Prototypes from file: " file.c "      */
 
 _PROTO(char *filedir, (int how_many, int downloading));
+_PROTO(void init_dir, (char dir));
 
 /*      Prototypes from file: " util.c "      */
 
@@ -189,9 +238,10 @@ _PROTO(int main, ( int argc , char **argv ));
 
 /*      Prototypes from file: " main.c "      */
 
-_PROTO(char *mbasename, ( char *s ));
 _PROTO(void leave, ( char *s ));
 _PROTO(char *esc_key, ( void ));
+_PROTO(void term_socket_connect, ( void ));
+_PROTO(void term_socket_close, ( void ));
 _PROTO(int open_term, ( int doinit ));
 _PROTO(void init_emul, ( int type , int do_init ));
 _PROTO(void timer_update, (void ));
@@ -212,7 +262,7 @@ _PROTO(void port_init, ( ));
  */
 #if _SEARCH_HISTORY
 _PROTO(void drawhist_look, (WIN *w, int y, int r, char *look, int case_matters));
-_PROTO(void searchhist, (WIN *w_orig, WIN *w_hist, int r, char *str));
+_PROTO(void searchhist, (WIN *w_hist, char *str));
 _PROTO(int find_next, (WIN *w, WIN *w_hist, int hit_line, char *look, int case_matters));
 _PROTO(const char *upcase, (char *dest, char *src));
 _PROTO(char *StrStr, (char *str1, char *str2, int case_matters));
@@ -244,6 +294,7 @@ _PROTO(void m_restorestate, ( int fd ));
 _PROTO(void m_nohang, ( int fd ));
 _PROTO(void m_hupcl, ( int fd, int on ));
 _PROTO(void m_flush, ( int fd ));
+_PROTO(void m_flush_script, ( int fd ));
 _PROTO(int m_getmaxspd, ( void ));
 _PROTO(void m_setparms, ( int fd , char *baudr , char *par , char *bits, char *stopb, int hwf, int swf ));
 _PROTO(int m_wait, ( int *st ));
@@ -288,3 +339,21 @@ _PROTO(int wxgetch, ( void ));
 
 _PROTO(void domacros, ( void ));
 
+
+
+
+
+
+/* We want the ANSI offsetof macro to do some dirty stuff. */
+#ifndef offsetof
+#  define offsetof(type, member) ((int) &((type *)0)->member)
+#endif
+
+/* Values for the "flags". */
+#define FL_ECHO		0x01	/* Local echo on/off. */
+#define FL_DEL		0x02	/* Backspace or DEL */
+#define FL_WRAP		0x04	/* Use autowrap. */
+#define FL_ANSI		0x08	/* Type of term emulation */
+#define FL_TAG		0x80	/* This entry is tagged. */
+#define FL_SAVE		0x0f	/* Which portions of flags to save. */
+
