@@ -28,7 +28,15 @@
  *    jl  28.11.98 - added P_SHOWSPD
  *    jl  05.04.99 - logging options
  *    er  18-Apr-99 - added P_MULTILINE for "multiline"
+ *    jl  10.02.2000 - added P_STOPB
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: rwconf.c,v 1.3 2003/03/31 08:40:09 godisch Exp $")
+
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
@@ -72,7 +80,7 @@ struct pars mpars[] = {
   { "",			PUBLIC,   "pname10" },
   { "",			PUBLIC,   "pname11" },
   { "",			PUBLIC,   "pname12" },
-#ifdef __linux__
+#if defined(__linux__) || defined(__GNU__)
   { "/usr/bin/sz -vv -b",	PUBLIC,   "pprog1" },
   { "/usr/bin/sb -vv",		PUBLIC,   "pprog2" },
   { "/usr/bin/sx -vv",		PUBLIC,   "pprog3" },
@@ -178,7 +186,7 @@ struct pars mpars[] = {
 #ifdef LOGFILE
   { LOGFILE,		PUBLIC,    "logfname" },
 #else
-  { "/dev/null",	PUBLIC,    "logfname" },
+  { "/dev/null",       	PUBLIC,    "logfname" },
 #endif
   { "Yes",		PUBLIC,    "logconn" },
   { "Yes",		PUBLIC,    "logxfer" },
@@ -242,13 +250,18 @@ int init;
   char *s;
   int public;
   int dosleep = 0;
+  int lineno = 0;
+  int matched;
 
   if (init) strcpy(P_SCRIPTPROG, "runscript");
 
   while(fgets(line, 80, fp) != (char *)0) {
 
+	lineno++;
+
   	s = strtok(line, "\n\t ");
 	if (s == NULL) continue;
+	if (*s == '#') continue;
 
   	/* Here we have pr for private and pu for public */
   	public = -1;
@@ -260,13 +273,21 @@ int init;
   		public = 1;
   		s = strtok((char *)NULL, "\n\t ");
   	}
-	if (s == NULL || public < 0) continue;
+	if (s == NULL || public < 0) {
+		fprintf(stderr,
+			_("** Line %d of the %s config file not understood\n"),
+		        lineno, init ? _("global") : _("personal"));
+		dosleep = 1;
+		continue;
+	}
 
   	/* Don't read private entries if prohibited */
   	if (!init && public == 0) continue;
 
+	matched = 0;
   	for(p = mpars; p->desc != (char *)0; p++) {
   		if (strcmp(p->desc, s) == 0) {
+		  	matched = 1;
 
 			/* See if this makes sense. */
 			if (((p->flags & PRIVATE) && public) ||
@@ -274,8 +295,8 @@ int init;
 				fprintf(stderr,
 			_("** Parameter %s is %s, but is marked %s in %s config file\n"),
 					s,
-					(p->flags & PRIVATE) ? "private" : "public",
-					public ? "public" : "private",
+					(p->flags & PRIVATE) ? _("private") : _("public"),
+					public ? _("public") : _("private"),
 					init ? _("global") : _("personal"));
 				dosleep = 1;
 			}
@@ -298,14 +319,22 @@ int init;
 			   for P_MUL if necessary - jl 5.4.98 */
 			if (!strncmp(p->desc,"pname",(size_t) 5)) {
 			  if (s[4] != 'N' && s[4] != 'Y') {
+#ifdef _SYSV
+			    memcpy (s+5, s+4, strlen(s+4));
+#else
+#ifdef _BSD43
+			    bcopy (s+4, s+5, strlen(s+4));
+#else
 			    memmove (s+5, s+4, strlen(s+4));
+#endif /* _BSD43 */
+#endif /* _SYSV */
 			    *(s+4)='N';
 			  }
 			}
 
   			/* If the same as default, don't mark as changed */
   			if (strcmp(p->value, s) == 0) {
-  				p->flags = 0;
+  				p->flags &= ~CHANGED;
   			} else {
 				if (init)
 					p->flags |= ADM_CHANGE;
@@ -321,6 +350,12 @@ int init;
   			break;
   		}
   	}
+	if (! matched) {
+		fprintf (stderr,
+			 _("** Line %d of the %s config file is unparsable.\n"),
+		         lineno, init ? _("global") : _("personal"));
+		dosleep = 1;
+  	}
   }
   /* To get over a bug in minicom 1.60 :( */
   if (strcmp(P_BAUDRATE, "Curr") == 0) strcpy(P_BAUDRATE, "38400");
