@@ -4,8 +4,6 @@
  *		This program also looks like a basic interpreter :
  *		a bit messy. (But hey, I'm no compiler writer :-))
  *
- * Version:	1.22
- *
  * Author:	Miquel van Smoorenburg, miquels@drinkel.ow.nl
  *
  * Bugs:	The "expect" routine is, unlike gosub, NOT reentrant !
@@ -21,7 +19,16 @@
  *
  * 10.07.98 jl  Added the log command
  * 05.04.99 jl  The logfile name should also be passed as a parameter
+ * 04.03.2002 jl Treat the ^ character between quotes as control code prefix
  */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID(PKG_VER "$Id: script.c,v 1.2 2003/03/30 19:51:53 godisch Exp $")
+
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
@@ -252,6 +259,15 @@ char **s;
   			continue;
   		}
   	}
+	/* ^ prefix for control chars - jl 3.2002 */
+	if (sawq == 1 && t[len] == '^' && t[len + 1] != 0) {
+		char c = toupper(t[len + 1]);
+		if (c >= 'A' && c <= '_') {
+			len++;
+			buf[idx++] = c - 'A' + 1;
+			continue;
+		}
+	}
   	if((!sawq && (t[len] == ' ' || t[len] == '\t')) || t[len] == 0) break;
   	buf[idx++] = t[len];
   }
@@ -522,7 +538,7 @@ char *text;
   		c = seq[f]->line[7];
   		if (c == 0 || (c != ' ' && c != '\t')) continue;
   		s = seq[f]->line + 7;
-  		seq[f] = LNULL;
+  		/* seq[f] = LNULL; */
   		skipspace(&s);
   		w = getword(&s);
   		if (w == CNULL) syntaxerr(_("(argument expected)"));
@@ -581,7 +597,7 @@ char *text;
 int dosend(text)
 char *text;
 {
-#ifdef __linux__
+#ifdef HAVE_USLEEP
   /* 200 ms delay. */
   usleep(200000);
 #endif
@@ -961,10 +977,10 @@ char **argv;
   signal(SIGHUP, SIG_IGN);
 #endif
 
-#ifdef _I18N_
-  bindtextdomain("minicom", "/usr/share/locale");
-  textdomain("minicom");
-#endif
+  /* initialize locale support */
+  setlocale(LC_ALL, "");
+  bindtextdomain(PACKAGE, LOCALEDIR);
+  textdomain(PACKAGE);
 
   init_env();
   memset(inbuf, 0, sizeof(inbuf));
