@@ -18,6 +18,13 @@
  * acme 25.02.98 i18n
  * js&jl 04.98	the better filename selection window
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: updown.c,v 1.1.1.1 2003/03/30 18:55:54 al-guest Exp $")
+
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
@@ -59,7 +66,7 @@ char *dir;
   	/* This may look safe but you might I8N change the string! so
   	   snprintf it */
   	snprintf(err, sizeof(err),  _("Cannot chdir to %.30s"), dir);
-  	werror(err);
+  	werror("%s", err);
   	return(-1);
   }
   return(0);
@@ -235,7 +242,7 @@ int nr;
 #endif
 
   if (P_LOGXFER[0] == 'Y')
-    do_log(cmdline);   /* jl 22.06.97 */
+    do_log("%s", cmdline);   /* jl 22.06.97 */
 
   if (P_PFULL(g) == 'N') {
     win = wopen(10, 7, 70, 13, BSINGLE, stdattr, mfcolor, mbcolor, 1, 0, 1);
@@ -302,11 +309,11 @@ int nr;
 			!strncmp (buffirst, "Sending", 7)) {
 		      if (xfrstr[0]) {
 			trim (trimbuf, xfrstr, sizeof(trimbuf));
-			do_log (trimbuf);
+			do_log ("%s", trimbuf);
 			xfrstr[0] = 0;
 		      }
 		      trim (trimbuf, buf, sizeof(trimbuf));
-		      do_log(trimbuf);
+		      do_log("%s", trimbuf);
 		    } else if (!strncmp (buffirst, "Bytes", 5)) {
 		      strncpy (xfrstr, buf, sizeof(xfrstr));
 		    }
@@ -323,7 +330,7 @@ int nr;
   /* Log the last file size	jl 14.09.97 */
   if (P_LOGXFER[0] == 'Y' && xfrstr[0]) {
     trim (trimbuf, xfrstr, sizeof(trimbuf));
-    do_log (trimbuf);
+    do_log ("%s", trimbuf);
     xfrstr[0] = 0;
   }
 
@@ -466,7 +473,7 @@ char *name, *value;
 
   for(e = environ; *e; e++) {
   	count++;
-  	if(varcmp(name, *e)) {
+  	if(varcmp(p, *e)) {
   		*e = p;
   		return(0);
   	}
