@@ -12,9 +12,16 @@
  * jseymour@jimsun.LinxNet.com (Jim Seymour) 03/26/98 - Added get_port()
  *    function to support multiple port specifications in config.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: util.c,v 1.1.1.1 2003/03/30 18:55:54 al-guest Exp $")
+
 #include "port.h"
 #include "minicom.h"
-
+#include "intl.h"
 
 static int not_suid = -1;
 
@@ -185,7 +192,7 @@ void drop_privs()
 #ifdef HAS_REUID
   setregid(eff_gid, real_gid);
   if (setreuid(eff_uid, real_uid) < 0)
-	fprintf(stderr, "minicom: cannot setreuid(%d, %d)\n", eff_uid, real_uid);
+	fprintf(stderr, _("minicom: cannot setreuid(%d, %d)\n"), eff_uid, real_uid);
   not_suid = 1;
 #endif
 }
@@ -196,7 +203,7 @@ void set_privs()
 #ifdef HAS_REUID
   setregid(real_gid, eff_gid);
   if (setreuid(real_uid, eff_uid) < 0)
-	fprintf(stderr, "minicom: cannot setreuid(%d, %d)\n", real_uid, eff_uid);
+	fprintf(stderr, _("minicom: cannot setreuid(%d, %d)\n"), real_uid, eff_uid);
   not_suid = 0;
 #endif
 }
