@@ -18,12 +18,18 @@
  * // jl 04.09.97 character map conversions in and out
  *    jl 06.07.98 use conversion tables with the capture file
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: vt100.c,v 1.2 2003/04/04 20:23:47 al-guest Exp $")
+
 #include "port.h"
 #include "window.h"
 #include "vt100.h"
 #include "config.h"
 #include "configsym.h"
-#include "patchlevel.h"
 
 #define OLD 0
 
@@ -154,9 +160,10 @@ static char *vt_trans[2];
 static int vt_charset = 0;	/* Character set. */
 #endif
 
-#ifdef _SELECT
+#ifdef HAVE_SELECT
 static int vt_echo;		/* Local echo on/off. */
 #endif
+int vt_nl_delay;		/* Delay after CR key */
 static int vt_type   = ANSI;	/* Terminal type. */
 static int vt_wrap   = 0;	/* Line wrap on/off */
 static int vt_addlf  = 0;	/* Add linefeed on/off */
@@ -249,7 +256,7 @@ int add;
   wresetregion(vt_win);
   vt_keypad = NORMAL;
   vt_cursor = NORMAL;
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   vt_echo = 0;
 #endif
   vt_tabs[0] = 0x01010100;
@@ -259,8 +266,8 @@ int add;
   vt_tabs[4] = 0x01010101;
 #if TRANSLATE
   vt_charset = 0;
-  vt_trans[0] = vt_map[0];
-  vt_trans[1] = vt_map[1];
+  vt_trans[0] = savetrans[0] = vt_map[0];
+  vt_trans[1] = savetrans[1] = vt_map[1];
 #endif
 #if OLD
   ptr = -2;
@@ -291,7 +298,7 @@ int asis;
   if (capfp != (FILE *)0) vt_capfp = capfp;
   if (docap >= 0) vt_docap = docap;
   if (bscode >= 0) vt_bs = bscode;
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   if (echo >= 0) vt_echo = echo;
 #endif
   if (cursor >= 0) vt_cursor = cursor;
@@ -303,7 +310,7 @@ static void v_termout(s, len)
 char *s;
 int len;
 {
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   char *p;
 
   if (vt_echo) {
@@ -947,7 +954,7 @@ int ch;
 			go_on = 1;
 			break;
 		}
-		v_termout(SCCS_ID, 0);
+		v_termout("Minicom" VERSION, 0);
 		break;
 	case '\r': /* Carriage return */
 		wputc(vt_win, c);
@@ -1074,6 +1081,8 @@ int c;
 		len = 2;
 	}
 	v_termout(s, len);
+	if (vt_nl_delay > 0 && c == '\r')
+		usleep(1000 * vt_nl_delay);
 	return;
   }
 
