@@ -12,6 +12,13 @@
  *
  * hgk+jl 02.98 File selection window (no longer used this way..)
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: windiv.c,v 1.2 2003/04/21 23:56:46 al-guest Exp $")
+
 #include <dirent.h>
 #include <sys/stat.h>
 #include "port.h"
@@ -75,7 +82,7 @@ char *s[];
   int cur = 0, ocur = 0;
   int f, c;
   WIN *w;
-  int size, offs;
+  unsigned int size, offs;
 
   for(f = 0; s[f]; f++) num++;
 
