@@ -14,6 +14,12 @@
  * 01.01.98 dickey@clark.net: fix for a history window closing bug
  * fmg 8/20/97: Added support for Search of History Buffer
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: window.c,v 1.3 2003/04/21 23:56:46 al-guest Exp $")
 
 #include "port.h"
 #include "window.h"
@@ -1054,9 +1060,8 @@ ELM *e;
  * 'accumulate' one line of ELM's into a string
  * WHY: need this in search function to see if line contains search pattern
  */
-void wdrawelm_var(w, y, e, buf)
+void wdrawelm_var(w, e, buf)
 WIN *w;
-int y;
 ELM *e;
 char *buf;
 {
@@ -1250,7 +1255,7 @@ char *title;
 int attr, fg, bg;
 {
   char **a = choices;
-  int len = 0;
+  unsigned int len = 0;
   int count = 0;
   int cur = 0;
   int c;
@@ -1260,12 +1265,14 @@ int attr, fg, bg;
   
   /* first count how many, and max. width. */
 
-  while(*a != CNULL) {
+  while (*a != CNULL) {
   	count++;
-  	if (strlen(_(*a)) > len) len = strlen(_(*a));
+  	if (strlen(_(*a)) > len)
+	      len = strlen(_(*a));
   	a++;
   }
-  if (title != CNULL && strlen(title) + 2 > len) len = strlen(title) + 2;
+  if (title != CNULL && strlen(title) + 2 > len)
+        len = strlen(title) + 2;
   if (attr & XA_REVERSE) {
   	high_on = attr & ~XA_REVERSE;
   	high_off = attr;
@@ -1778,7 +1785,7 @@ int maxlen;
 			}
 
 			/* Insert character at cursor position. */
-			if (c < 32 || c > 127) break;
+			if (c < 32 || c > 255) break;
 			if (idx + 1 >= maxlen) break;
 			for(f = strlen(buf) + 1; f > idx; f--)
 				buf[f] = buf[f-1];
@@ -1846,16 +1853,16 @@ int attr;
 
 #ifndef BBS
   if ((term = getenv("TERM")) == CNULL) {
-  	fprintf(stderr, "Environment variable TERM not set\n");
+  	fprintf(stderr, _("Environment variable TERM not set\n"));
 	return(-1);
   }
 #endif
   switch((f = tgetent(cbuf, term))) {
   	case 0:
-  		fprintf(stderr, "No termcap entry for %s\n", term);
+  		fprintf(stderr, _("No termcap entry for %s\n"), term);
   		return(-1);
   	case -1:
-  		fprintf(stderr, "No termcap database present!\n");
+  		fprintf(stderr, _("No termcap database present!\n"));
   		return(-1);
   	default:
   		break;
@@ -1863,7 +1870,7 @@ int attr;
   _tptr = tbuf;
 
   if ((CM = tgetstr("cm", &_tptr)) == CNULL) {
-  	fprintf(stderr, "No cursor motion capability (cm)\n");
+  	fprintf(stderr, _("No cursor motion capability (cm)\n"));
   	return(-1);
   }
   LINES = COLS = 0;
@@ -1872,11 +1879,11 @@ int attr;
   LINES = lines;
 #endif
   if (LINES == 0 && (LINES = tgetnum("li")) <= 0) {
-  	fprintf(stderr, "Number of terminal lines unknown\n");
+  	fprintf(stderr, _("Number of terminal lines unknown\n"));
   	return(-1);
   }
   if (COLS == 0 && (COLS = tgetnum("co")) <= 0) {
-  	fprintf(stderr, "Number of terminal columns unknown\n");
+  	fprintf(stderr, _("Number of terminal columns unknown\n"));
   	return(-1);
   }
 
