@@ -1,6 +1,8 @@
 /*
  * window.h	Constants, prototypes etc. for the window routines.
  *
+ * 		$Id: window.h,v 1.2 2003/04/21 23:56:46 al-guest Exp $
+ *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1996 Miquel van Smoorenburg.
  *
@@ -192,7 +194,7 @@ _PROTO(int win_init, ( int fg , int bg , int attr ));
 /* fmg 8/20/97: both needed by history search section */
 #ifdef HISTORY
 _PROTO(void wdrawelm_inverse, ( WIN *w, int y, ELM *e ));
-_PROTO(void wdrawelm_var, (WIN *w, int y, ELM *e, char *buf ));
+_PROTO(void wdrawelm_var, (WIN *w, ELM *e, char *buf ));
 _PROTO(char *StrStr, (char *str1, char *str2, int case_matters ));
 #endif
 
