@@ -12,9 +12,18 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: wkeys.c,v 1.3 2003/04/19 16:31:27 al-guest Exp $")
+
+#include <strings.h>
+
 #include "port.h"
 #include "minicom.h"
-
+#include "intl.h"
 
 #if KEY_KLUDGE && defined(linux)
 #  include <sys/kd.h>
@@ -110,16 +119,16 @@ static void _initkeys()
   if (_tptr == CNULL) {
 	if ((tbuf = (char *)malloc(512)) == CNULL || 
 		(cbuf = (char *)malloc(2048)) == CNULL) {
-  		write(2, "Out of memory.\n", 15);
+  		write(2, _("Out of memory.\n"), 15);
   		exit(1);
 	}
 	term = getenv("TERM");
 	switch(tgetent(cbuf, term)) {
   		case 0:
-  			write(2, "No termcap entry.\n", 18);
+  			write(2, _("No termcap entry.\n"), 18);
   			exit(1);
   		case -1:
-  			write(2, "No /etc/termcap present!\n", 25);
+  			write(2, _("No /etc/termcap present!\n"), 25);
   			exit(1);
   		default:
   			break;
@@ -140,8 +149,8 @@ static void _initkeys()
 /*
  * Dummy routine for the alarm signal
  */
-#ifndef _SELECT
-static void dummy()
+#ifndef HAVE_SELECT
+static void dummy_alarm()
 {
   gotalrm = 1;
 }
@@ -165,7 +174,7 @@ int wxgetch()
 #if VT_KLUDGE
   char temp[8];
 #endif
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   struct timeval timeout;
   fd_set readfds;
   static fd_set *nofds = (fd_set *)0;
@@ -188,7 +197,7 @@ int wxgetch()
   pendingkeys = 0;
 
   for (len = 1; len < 8 && match; len++) {
-#ifdef _SELECT
+#ifdef HAVE_SELECT
 #if KEY_KLUDGE
 	if (len > 1 && keys_in_buf == 0) {
 #else
@@ -213,12 +222,12 @@ int wxgetch()
 			break;
 		}
 	}
-#else /* _SELECT */
+#else /* HAVE_SELECT */
 	if (len > 1) {
-		signal(SIGALRM, dummy);
+		signal(SIGALRM, dummy_alarm);
 		alarm(1);
 	}
-#endif /* _SELECT */
+#endif /* HAVE_SELECT */
 
 #if KEY_KLUDGE
 	while((nfound = cread(&c)) < 0 && (errno == EINTR && !gotalrm))
@@ -228,7 +237,7 @@ int wxgetch()
   		;
 #endif
 
-#ifndef _SELECT
+#ifndef HAVE_SELECT
 	if (len > 1) alarm(0);
 #endif
 	if (nfound < 1) break;
@@ -298,7 +307,7 @@ int wxgetch()
   pendingkeys++;
   io_pending++;
 
-#ifndef _SELECT
+#ifndef HAVE_SELECT
   /* Pressing eg escape twice means escape */
   if (len == 2 && mem[0] == mem[1]) return(mem[0]);
 #endif
